@@ -6,7 +6,7 @@
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)               */
 /*                      2003-2008 Benjamin Drieu (bdrieu@april.org)              */
 /*          2008-2018 Pierre Biava (grisbi@pierre.biava.name)                    */
-/*          https://www.grisbi.org/                                               */
+/*          https://www.grisbi.org/                                              */
 /*                                                                               */
 /*     This program is free software; you can redistribute it and/or modify      */
 /*     it under the terms of the GNU General Public License as published by      */
@@ -44,15 +44,23 @@
 #include "utils_prefs.h"
 #include "utils_str.h"
 #include "erreur.h"
-
 /*END_INCLUDE*/
 
 /*START_EXTERN*/
 /*END_EXTERN*/
 
+#define GSB_RESPONSE_EDIT 5
+
+typedef struct _CsvTemplateRule			CsvTemplateRule;
+
 typedef struct _CsvTemplateRulePrivate	CsvTemplateRulePrivate;
 typedef struct _SpecWidgetLine			SpecWidgetLine;
 
+struct _CsvTemplateRule
+{
+    GtkDialog 		parent;
+};
+
 struct _CsvTemplateRulePrivate
 {
 	GtkWidget *		dialog_csv_template;
@@ -188,7 +196,7 @@ static void csv_template_rule_notebook_page_reordered (GtkNotebook *notebook,
             										  	CsvTemplateRule *template_rule)
 {
 	GSList *tmp_list;
-	const gchar *tmp_str;
+	gchar *tmp_str;
 	gint tmp_number;
 	CsvTemplateRulePrivate *priv;
 
@@ -196,8 +204,9 @@ static void csv_template_rule_notebook_page_reordered (GtkNotebook *notebook,
 	priv = csv_template_rule_get_instance_private (template_rule);
 
 	/* on regarde quel onglet à bougé */
-	tmp_str = gtk_notebook_get_tab_label_text (notebook, child);
-	tmp_number = utils_str_atoi (gsb_string_extract_int (tmp_str));
+	tmp_str = gsb_string_extract_int (gtk_notebook_get_tab_label_text (notebook, child));
+	tmp_number = utils_str_atoi (tmp_str);
+	g_free(tmp_str);
 
 	/* on balaie la liste des lignes pour placer la ligne modifiée au bon endroit */
 	tmp_list = priv->list_spec_lines;
@@ -585,6 +594,8 @@ static SpecWidgetLine *csv_template_rule_spec_conf_new_line (CsvTemplateRule *te
 	grid = gtk_grid_new ();
 	gtk_grid_set_column_spacing (GTK_GRID (grid), MARGIN_BOX);
 	gtk_grid_set_row_spacing (GTK_GRID (grid), MARGIN_BOX);
+	gtk_widget_set_margin_bottom (grid, MARGIN_BOX);
+	gtk_widget_set_margin_top (grid, MARGIN_BOX);
 
 	label = gtk_label_new ("    ");
 	gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
@@ -805,9 +816,9 @@ static void csv_template_dialog_response  (GtkDialog *dialog,
 				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (line_struct->checkbutton)))
 				{
 					GtkWidget *widget;
-					SpecConfData *spec_conf_data;
+					CsvSpecConfData *spec_conf_data;
 
-					spec_conf_data = g_malloc0 (sizeof (SpecConfData));
+					spec_conf_data = g_malloc0 (sizeof (CsvSpecConfData));
 					widget = line_struct->combobox_action;
 					spec_conf_data->csv_spec_conf_action = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 					if (spec_conf_data->csv_spec_conf_action == 1)
@@ -859,9 +870,9 @@ static void csv_template_dialog_response  (GtkDialog *dialog,
 					if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (line_struct->checkbutton)))
 					{
 						GtkWidget *widget;
-						SpecConfData *spec_conf_data;
+						CsvSpecConfData *spec_conf_data;
 
-						spec_conf_data = g_malloc0 (sizeof (SpecConfData));
+						spec_conf_data = g_malloc0 (sizeof (CsvSpecConfData));
 						widget = line_struct->combobox_action;
 						spec_conf_data->csv_spec_conf_action = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 						if (spec_conf_data->csv_spec_conf_action == 1)
@@ -949,7 +960,7 @@ static void csv_template_rule_setup_dialog (CsvTemplateRule *template_rule,
 	g_free (tmp_str);
 
 	/* set the notebook action widget */
-	button = utils_buttons_button_new_from_image ("gtk-add-16.png");
+	button = utils_buttons_button_new_from_resource ("gtk-add-16.png");
 	gtk_widget_show (button);
 	gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
 	gtk_notebook_set_action_widget (GTK_NOTEBOOK (priv->notebook_csv_spec), button, GTK_PACK_START);
@@ -1024,7 +1035,7 @@ static void csv_template_rule_edit_dialog (CsvTemplateRule *template_rule,
 	g_object_set_data (G_OBJECT (template_rule), "rule_number", GINT_TO_POINTER (rule_number));
 
 	/* set the notebook action widget */
-	button = utils_buttons_button_new_from_image ("gtk-add-16.png");
+	button = utils_buttons_button_new_from_resource ("gtk-add-16.png");
 	gtk_widget_show (button);
 	gtk_notebook_set_action_widget (GTK_NOTEBOOK (priv->notebook_csv_spec), button, GTK_PACK_START);
 	priv->button_csv_spec_add_line = button;
@@ -1084,9 +1095,9 @@ static void csv_template_rule_edit_dialog (CsvTemplateRule *template_rule,
 		while (list)
 		{
 			SpecWidgetLine *line_struct;
-			SpecConfData *spec_conf_data;
+			CsvSpecConfData *spec_conf_data;
 
-			spec_conf_data = (SpecConfData *) list->data;
+			spec_conf_data = (CsvSpecConfData *) list->data;
 
 			/* set the spec line */
 			line_struct = csv_template_rule_spec_conf_new_line (template_rule, index);
@@ -1278,7 +1289,7 @@ void csv_template_rule_csv_import_rule_struct_free	(CSVImportRule *rule)
 	list = rule->csv_spec_lines_list;
 	while (list)
 	{
-		SpecConfData *spec_conf_data;
+		CsvSpecConfData *spec_conf_data;
 
 		spec_conf_data = list->data;
 		if (spec_conf_data)
@@ -1298,12 +1309,12 @@ void csv_template_rule_csv_import_rule_struct_free	(CSVImportRule *rule)
  *
  * \return
  **/
-SpecConfData *csv_template_rule_spec_conf_data_struct_copy (SpecConfData *spec_conf_data,
-															 gpointer data)
+CsvSpecConfData *csv_template_rule_spec_conf_data_struct_copy (CsvSpecConfData *spec_conf_data,
+															   gpointer data)
 {
-	SpecConfData *new_struct;
+	CsvSpecConfData *new_struct;
 
-	new_struct = g_malloc0 (sizeof (SpecConfData));
+	new_struct = g_malloc0 (sizeof (CsvSpecConfData));
 	new_struct->csv_spec_conf_action = spec_conf_data->csv_spec_conf_action;
 	new_struct->csv_spec_conf_action_data = spec_conf_data->csv_spec_conf_action_data;
 	new_struct->csv_spec_conf_used_data = spec_conf_data->csv_spec_conf_used_data;
