@@ -205,7 +205,7 @@ void gsb_partial_balance_fill_model ( GtkListStore *list_store )
     {
         struct_partial_balance *partial_balance;
         gchar *kind_str;
-        gchar *currency_str = (gchar*)"";
+        gchar *currency_str;
 
         partial_balance = list_tmp -> data;
 
@@ -278,7 +278,7 @@ void gsb_partial_balance_add ( GtkWidget *button, GtkWidget *main_widget )
 dialog_return:
     result = gtk_dialog_run ( GTK_DIALOG ( dialog ) );
 
-    if ( result == 1)
+    if (result == GTK_RESPONSE_OK)
     {
         GtkTreeView *treeview;
         GtkTreeModel *model;
@@ -397,7 +397,7 @@ void gsb_partial_balance_edit ( GtkWidget *button, GtkWidget *main_widget )
 dialog_return:
     result = gtk_dialog_run ( GTK_DIALOG ( dialog ));
 
-    if ( result == 1)
+    if (result == GTK_RESPONSE_OK)
     {
         const gchar *name, *new_liste_cptes;
         gint position;
@@ -1244,9 +1244,11 @@ gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
                 gtk_tree_model_get ( model, &iter, 1, &account_nb, -1);
                 if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) > 0 )
                 {
+					gchar *tmp_str = g_strdup_printf ( "%d", account_nb );
                     gtk_entry_set_text ( GTK_ENTRY ( entry ),
                                 g_strconcat ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ), ";",
-                                g_strdup_printf ( "%d", account_nb ), NULL ) );
+                                tmp_str, NULL));
+					g_free(tmp_str);
                 }
                 else
                     gtk_entry_set_text ( GTK_ENTRY ( entry ), g_strdup_printf ( "%d", account_nb ) );
@@ -1267,12 +1269,21 @@ gboolean gsb_partial_balance_select_account ( GtkTreeSelection *selection,
             gtk_tree_model_get ( model, &iter, 1, &account_nb, -1);
             if ( strlen ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ) ) > 0 )
             {
-                gtk_entry_set_text ( GTK_ENTRY ( entry ),
-                            g_strconcat ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ), ";",
-                            g_strdup_printf ( "%d", account_nb ), NULL ) );
+				gchar *tmp_str1, *tmp_str2;
+				tmp_str1 = g_strdup_printf ( "%d", account_nb );
+				tmp_str2 = g_strconcat ( gtk_entry_get_text ( GTK_ENTRY ( entry ) ), ";",
+										tmp_str1, NULL );
+                gtk_entry_set_text ( GTK_ENTRY ( entry ), tmp_str2);
+				g_free(tmp_str1);
+				g_free(tmp_str2);
             }
             else
-                gtk_entry_set_text ( GTK_ENTRY ( entry ), g_strdup_printf ( "%d", account_nb ) );
+			{
+				gchar *tmp_str1;
+				tmp_str1 = g_strdup_printf ( "%d", account_nb );
+                gtk_entry_set_text ( GTK_ENTRY ( entry ), tmp_str1 );
+				g_free(tmp_str1);
+			}
 
             list = list -> next;
         }
@@ -1625,7 +1636,6 @@ void gsb_data_partial_balance_renum_account_number_0 (gint account_number)
 
         partial_balance = tmp_list->data;
 		liste_cptes = partial_balance->liste_cptes;
-		printf ("liste_cptes = %s\n", liste_cptes);
 		if (g_strstr_len (liste_cptes, -1, "0"))
 		{
 			gchar **tab;
@@ -1650,13 +1660,73 @@ void gsb_data_partial_balance_renum_account_number_0 (gint account_number)
 					new_str = g_strjoinv (";", tab);
 					g_free (partial_balance->liste_cptes);
 					partial_balance->liste_cptes = new_str;
-					g_strfreev (tab);
 					break;
 				}
 			}
+			g_strfreev (tab);
+		}
+		tmp_list = tmp_list->next;
+	}
+}
+
+/**
+ *
+ *
+ * \param
+ *
+ * \return
+ **/
+void gsb_partial_balance_remove_from_account (gint deleted_account)
+{
+	GSList *tmp_list;
+	gchar *deleted_account_str;
+
+	deleted_account_str = utils_str_itoa (deleted_account);
+	tmp_list = partial_balance_list;
+	while (tmp_list)
+	{
+		gchar *liste_cptes;
+		struct_partial_balance *partial_balance;
+
+		partial_balance = tmp_list->data;
+		liste_cptes = partial_balance->liste_cptes;
+		if (g_strstr_len (liste_cptes, -1, deleted_account_str))
+		{
+			gchar **tab;
+			gint i;
+			gint nbre_elements = 0;
+
+			tab = g_strsplit (liste_cptes, ";", 0);
+			nbre_elements = g_strv_length (tab);
+			for ( i = 0; tab[i]; i++ )
+			{
+				gint account_nb;
+
+				account_nb = utils_str_atoi (tab[i]);
+				if (account_nb == deleted_account)
+				{
+					gchar *str_to_free_1 = NULL;
+					gchar *str_to_free_2;
+
+					if (i == 0)
+					{
+						str_to_free_1 = g_strconcat (tab[i], ";", NULL);
+					}
+					else
+					{
+						str_to_free_1 = g_strconcat (";", tab[i], NULL);
+					}
+					str_to_free_2 = partial_balance->liste_cptes;
+					partial_balance->liste_cptes = gsb_string_remplace_string (str_to_free_2, str_to_free_1, "");
+					g_free(str_to_free_1);
+					nbre_elements--;
+				}
+
+			}
 		}
 		tmp_list = tmp_list->next;
 	}
+	g_free(deleted_account_str);
 }
 
 /*********************************************************************************************/
@@ -1754,25 +1824,34 @@ GtkWidget *gsb_partial_balance_create_list_accounts ( GtkWidget *entry )
 GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 {
     GtkWidget *dialog, *label, *main_vbox;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     GtkWidget *paddinggrid;
     GtkWidget *entry_name, *entry_list, *account_list, *bouton;
+	gchar *tmp_str;
 
     devel_debug ( NULL);
 
-    if ( action == 1 )
-        dialog = gtk_dialog_new_with_buttons ( _("Add a partial balance"),
-                            GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-                            GTK_DIALOG_MODAL,
-                            "gtk-cancel", 0,
-                            "gtk-ok", 1,
-                            NULL );
-    else
-        dialog = gtk_dialog_new_with_buttons ( _("Modify a partial balance"),
-                            GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
-                            GTK_DIALOG_MODAL,
-                            "gtk-cancel", 0,
-                            "gtk-ok", 1,
-                            NULL );
+	if (action == 1)
+		tmp_str = g_strdup (_("Add a partial balance"));
+	else
+		tmp_str = g_strdup (_("Modify a partial balance"));
+
+	dialog = gtk_dialog_new_with_buttons (tmp_str,
+										  GTK_WINDOW ( grisbi_app_get_active_window (NULL) ),
+										  GTK_DIALOG_MODAL,
+										  NULL, NULL,
+										  NULL);
+	g_free (tmp_str);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_OK, TRUE);
+
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
     main_vbox = new_vbox_with_title_and_icon ( _("Partial balance details"), "gsb-payment-32.png" );
@@ -1834,7 +1913,6 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
     return dialog;
 }
 
-
 /**
  *
  *
@@ -1842,15 +1920,25 @@ GtkWidget *gsb_partial_balance_create_dialog ( gint action, gint spin_value )
 gint gsb_partial_balance_request_currency ( GtkWidget *parent )
 {
     GtkWidget *dialog, *hbox, *label, *combo_devise;
+	GtkWidget *button_cancel;
+	GtkWidget *button_OK;
     gint currency_nb = 1;	/* Initialisation avec la première devise : fixe bug 1881 */
 
-    dialog = gtk_dialog_new_with_buttons ( _("Enter the currency of the balance part"),
-                            GTK_WINDOW ( parent ),
-                            GTK_DIALOG_MODAL,
-                            "gtk-cancel", 0,
-                            "gtk-ok", 1,
-                            NULL );
-    gtk_widget_set_size_request ( dialog, -1, 150 );
+    dialog = gtk_dialog_new_with_buttons (_("Enter the currency of the balance part"),
+										  GTK_WINDOW (parent),
+										  GTK_DIALOG_MODAL,
+										  NULL, NULL,
+										  NULL);
+
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_OK = gtk_button_new_with_label (_("Validate"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_OK, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default (button_OK, TRUE);
+
+	gtk_widget_set_size_request ( dialog, -1, 150 );
     gtk_window_set_position ( GTK_WINDOW ( dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
 
     hbox = gtk_box_new ( GTK_ORIENTATION_HORIZONTAL, MARGIN_BOX );
