@@ -43,6 +43,7 @@
 #include "gsb_data_payment.h"
 #include "gsb_data_scheduled.h"
 #include "gsb_data_transaction.h"
+#include "gsb_form_scheduler.h"
 #include "gsb_form_transaction.h"
 #include "gsb_file.h"
 #include "gsb_scheduler_list.h"
@@ -318,8 +319,8 @@ GDate *gsb_scheduler_get_next_date ( gint scheduled_number,
  *
  * \return the number of the new transaction
  * */
-gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint scheduled_number,
-								   gint transaction_mother )
+gint gsb_scheduler_create_transaction_from_scheduled_transaction (gint scheduled_number,
+																  gint transaction_mother )
 {
 	GDate *date;
     gint account_number;
@@ -328,13 +329,18 @@ gint gsb_scheduler_create_transaction_from_scheduled_transaction ( gint schedule
     gint transaction_number;
 
 	devel_debug_int (scheduled_number);
-    account_number = gsb_data_scheduled_get_account_number (scheduled_number);
+	account_number = gsb_data_scheduled_get_account_number (scheduled_number);
 
 	transfer_account = gsb_data_scheduled_get_account_number_transfer (scheduled_number+1);
     transaction_number = gsb_data_transaction_new_transaction (account_number);
 
-	/* initialise les données pour fixed date */
-	date = gsb_data_scheduled_get_date (scheduled_number);
+	/* initialise les données pour fixed date fix bug 2164: récupère la date de la transaction mère */
+	if (transaction_mother)
+	{
+		date = gsb_data_scheduled_get_date (gsb_data_scheduled_get_mother_scheduled_number (scheduled_number));
+	}
+	else
+		date = gsb_data_scheduled_get_date (scheduled_number);
 
 	/* begin to fill the new transaction */
     gsb_data_transaction_set_date (transaction_number, date);
@@ -553,7 +559,33 @@ devel_debug (NULL);
     return FALSE;
 }
 
+/**
+ * update the children of a split scheduled transaction,
+ *
+ * \param scheduled_number the number of the mother scheduled transaction (the split)
+ *
+ * \return FALSE
+ *
+ **/
+void gsb_scheduler_update_children_from_split_scheduled (gint scheduled_number)
+{
+    GSList *children_numbers_list;
 
+    children_numbers_list = gsb_data_scheduled_get_children (scheduled_number, TRUE);
+    while (children_numbers_list)
+    {
+		gint child_number;
+
+		child_number = GPOINTER_TO_INT (children_numbers_list->data);
+		if (child_number > 0)
+		{
+			gsb_form_scheduler_set_from_mother (child_number, scheduled_number);
+		}
+
+		children_numbers_list = children_numbers_list -> next;
+    }
+    g_slist_free (children_numbers_list);
+}
 
 /**
  * check the scheduled transactions if the are in time limit
@@ -569,9 +601,11 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
     GSList *tmp_list;
     gboolean automatic_transactions_taken = FALSE;
 	GrisbiAppConf *a_conf;
+	GrisbiWinRun *w_run;
 
     devel_debug (NULL);
 	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 
     /* the scheduled transactions to take will be check here,
      * but the scheduled transactions taken will be add to the already appended ones */
@@ -674,12 +708,12 @@ void gsb_scheduler_check_scheduled_transactions_time_limit ( void )
 
     if ( automatic_transactions_taken )
     {
-        run.mise_a_jour_liste_echeances_auto_accueil = TRUE;
+        w_run->mise_a_jour_liste_echeances_auto_accueil = TRUE;
         gsb_file_set_modified ( TRUE );
     }
 
     if ( scheduled_transactions_to_take )
-		run.mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
+		w_run->mise_a_jour_liste_echeances_manuelles_accueil = TRUE;
 
     g_date_free ( date );
 }
