@@ -3,7 +3,7 @@
 /*     Copyright (C)    2000-2003 Cédric Auger  (cedric@grisbi.org)           */
 /*          2004-2006 Benjamin Drieu (bdrieu@april.org)                       */
 /*                      2008-2018 Pierre Biava (grisbi@pierre.biava.name)     */
-/*          https://www.grisbi.org/                                            */
+/*          https://www.grisbi.org/                                           */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
 /*  it under the terms of the GNU General Public License as published by      */
@@ -30,9 +30,11 @@
 
 /*START_INCLUDE*/
 #include "import_csv.h"
+#include "classement_echeances.h"
 #include "csv_parse.h"
 #include "csv_template_rule.h"
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_automem.h"
 #include "gsb_data_import_rule.h"
 #include "import.h"
@@ -41,6 +43,7 @@
 #include "utils_dates.h"
 #include "utils_real.h"
 #include "utils_str.h"
+#include "utils_widgets.h"
 #include "erreur.h"
 /*END_INCLUDE*/
 
@@ -64,9 +67,17 @@ static gint first_line_with_cols;
 /* data for rule */
 static gboolean csv_create_rule = FALSE;
 
+struct CsvField {
+    const gchar *	name;
+    gfloat			alignment;
+    gboolean		(*validate) (gchar *);
+    gboolean		(*parse) (struct ImportTransaction *, gchar *);
+    const gchar *	alias;
+};
+
 /** Contain configuration of CSV fields.  */
 /* NAME, ALIGNMENT, VALIDATE FUNCTION, PARSE FUNCTION, ALIAS */
-struct csv_field csv_fields[18] = {
+struct CsvField csv_fields[18] = {
 	{ N_("Unknown field"),  	0.0, NULL,			     		 NULL		     ,				"" },				/* 0 */
 	{ N_("Currency"),	    	0.0, csv_import_validate_string, csv_import_parse_currency, 	"" },				/* 1 */
 	{ N_("Date"),	    		0.0, csv_import_validate_date,   csv_import_parse_date, 		"" },				/* 2 */
@@ -87,10 +98,6 @@ struct csv_field csv_fields[18] = {
 	{ NULL, 0.0, NULL, NULL, NULL },
 };
 
-
-
-
-
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
@@ -162,7 +169,7 @@ static void csv_import_free_lines_tab (GArray *lines_tab)
  **/
 static gchar *gsb_file_test_and_load_csv_file (struct ImportFile *imported)
 {
-	gchar* tmp_str1;
+	gchar* tmp_str1 = NULL;
     gchar *contents;
     gsize size;
     gsize bytes_written;
@@ -182,6 +189,7 @@ static gchar *gsb_file_test_and_load_csv_file (struct ImportFile *imported)
 	{
 		gchar *tmp_str2;
 
+		g_free(tmp_str1);
 		tmp_str2 = g_path_get_basename (imported->name);
 		tmp_str1 = g_strdup_printf ( _("The file %s is empty. Please choose another file."), tmp_str2);
         dialogue_warning_hint (tmp_str1, _("File empty."));
@@ -219,6 +227,7 @@ static gchar *gsb_file_test_and_load_csv_file (struct ImportFile *imported)
         {
             g_print (_("Unable to read file: %s\n"), error->message);
             g_error_free (error);
+			g_free (tmp_str1);
             return FALSE;
         }
     }
@@ -264,7 +273,7 @@ static gchar *csv_import_button_rule_get_account_id (GArray *lines_tab,
  *
  * \return
  **/
-static GArray *csv_import_button_rule_traite_spec_line (SpecConfData *spec_conf_data,
+static GArray *csv_import_button_rule_traite_spec_line (CsvSpecConfData *spec_conf_data,
 														GArray *lines_tab,
 														gint index)
 {
@@ -344,7 +353,7 @@ static GArray *csv_import_button_rule_traite_spec_line (SpecConfData *spec_conf_
 				}
 				str_montant = utils_real_get_string (montant);
 				list = g_slist_delete_link (list, link);
-				list = g_slist_insert (list, g_strdup (str_montant), spec_conf_data->csv_spec_conf_action_data);
+				list = g_slist_insert (list, str_montant, spec_conf_data->csv_spec_conf_action_data);
 				if (!list)
 					notice_debug ("Warning: Invalid data");
 			}
@@ -387,7 +396,7 @@ static void csv_import_button_rule_clicked (GtkButton *button,
 	{
 		GSList *list;
 		gint i = 0;
-		SpecConfData *spec_conf_data;
+		CsvSpecConfData *spec_conf_data;
 
 		csv_create_rule = TRUE;
 		g_object_set_data (G_OBJECT (assistant), "csv-import-rule", csv_import_rule);
@@ -398,7 +407,7 @@ static void csv_import_button_rule_clicked (GtkButton *button,
 			return;
 		}
 
-		spec_conf_data = (SpecConfData *) list->data;
+		spec_conf_data = (CsvSpecConfData *) list->data;
 		if (spec_conf_data->csv_spec_conf_used_text)
 		{
 			GArray *lines_tab;
@@ -409,7 +418,7 @@ static void csv_import_button_rule_clicked (GtkButton *button,
 				gint action;
 				gint index;
 				if (i)
-					spec_conf_data = (SpecConfData *) list->data;
+					spec_conf_data = (CsvSpecConfData *) list->data;
 
 				/* détermination de la première transaction du fichier */
 				action = spec_conf_data->csv_spec_conf_action;
@@ -609,18 +618,20 @@ static gint *csv_import_guess_fields_config (GArray *lines_tab,
 	gboolean date_validated = 0;
 	gboolean is_credit = FALSE;
 	gboolean is_debit = FALSE;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
     default_config = (gint *) g_malloc0 ((size + 1) * sizeof (int));
 
 	/* force skip first lines */
 	for (i = 0; i <= first_line_with_cols; i++)
 	{
-		etat.csv_skipped_lines [i] = 1;
+		w_etat->csv_skipped_lines [i] = 1;
 	}
 	/* init other lines to 0 */
 	for (; i <CSV_MAX_TOP_LINES; i++)
 	{
-		etat.csv_skipped_lines [i] = 0;
+		w_etat->csv_skipped_lines [i] = 0;
 	}
 
     list = g_array_index (lines_tab, GSList *, first_line_with_cols);
@@ -811,6 +822,7 @@ static void csv_import_update_validity_check (GtkWidget *assistant)
 {
     int i, needed[] = { 2, 4, -1 };
     gchar *label = NULL;
+	gchar *new_label;
 
     if (!csv_fields_config)
 		return;
@@ -822,11 +834,13 @@ static void csv_import_update_validity_check (GtkWidget *assistant)
 		{
 			if (label)
 			{
-				label = g_strconcat (label, ", ", _(csv_fields [needed [i]].name), NULL);
+				new_label = g_strconcat (label, ", ", _(csv_fields [needed [i]].name), NULL);
+				g_free(label);
+				label = new_label;
 			}
 			else
 			{
-				label = _(csv_fields [needed [i]].name);
+				label = my_strdup(_(csv_fields [needed [i]].name));
 			}
 		}
     }
@@ -848,7 +862,9 @@ static void csv_import_update_validity_check (GtkWidget *assistant)
     {
         if (label)
         {
-            label = g_strconcat (label, ", ", _("Transaction amount"), NULL);
+            new_label = g_strconcat (label, ", ", _("Transaction amount"), NULL);
+			g_free(label);
+			label = new_label;
         }
         else
         {
@@ -868,6 +884,7 @@ static void csv_import_update_validity_check (GtkWidget *assistant)
 		gtk_widget_set_sensitive (g_object_get_data (G_OBJECT (assistant),
 													 "button_next"),
 								  FALSE);
+		g_free(label);
     }
     else
     {
@@ -979,11 +996,7 @@ static gboolean csv_import_header_on_click (GtkWidget *button,
 								   GPOINTER_TO_INT (no_column),
 								   g_object_get_data (G_OBJECT(col), "assistant"));
 
-#if GTK_CHECK_VERSION (3,22,0)
 	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
-#else
-	gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, 3, gtk_get_current_event_time());
-#endif
 
     return FALSE;
 }
@@ -1008,7 +1021,9 @@ static void skip_line_toggled (GtkCellRendererToggle *cell,
     gint *indices;
     GtkTreePath *path;
     GtkTreeModel *tree_model;
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
 	path = gtk_tree_path_new_from_string (path_str);
 	tree_model = gtk_tree_view_get_model (tree_preview);
 
@@ -1018,7 +1033,7 @@ static void skip_line_toggled (GtkCellRendererToggle *cell,
     gtk_tree_store_set (GTK_TREE_STORE (tree_model), &iter, 0, !toggle_item, -1);
 
     indices = gtk_tree_path_get_indices (path);
-    etat.csv_skipped_lines [indices[0]] = !toggle_item;
+    w_etat->csv_skipped_lines [indices[0]] = !toggle_item;
 }
 
 /**
@@ -1222,8 +1237,12 @@ static gboolean csv_import_update_preview (GtkWidget *assistant)
     GtkTreeView *tree_preview;
     GSList *list;
     gint line = 0;
+	GrisbiWinEtat *w_etat;
+	GrisbiWinRun *w_run;
 
 	devel_debug (NULL);
+	w_etat = grisbi_win_get_w_etat ();
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
     separator = g_object_get_data (G_OBJECT(assistant), "separator");
     tree_preview = g_object_get_data (G_OBJECT(assistant), "tree_preview");
 	lines_tab = g_object_get_data (G_OBJECT(assistant), "lines-tab");
@@ -1255,10 +1274,9 @@ static gboolean csv_import_update_preview (GtkWidget *assistant)
 
         list = g_array_index (lines_tab, GSList *, line);
 
-        if (!list)
+        if (!list)	/* le nombre de lignes est < CSV_MAX_TOP_LINES, on sort */
         {
-			csv_import_update_validity_check (assistant);
-            return FALSE;
+			break;
         }
 
         gtk_tree_store_append (GTK_TREE_STORE (model), &iter, NULL);
@@ -1267,16 +1285,13 @@ static gboolean csv_import_update_preview (GtkWidget *assistant)
 			gchar *tmp_str;
 
 			tmp_str = gsb_string_truncate (list->data);
-            gtk_tree_store_set (GTK_TREE_STORE (model),
-								&iter,
-								col, tmp_str,
-								-1);
+            gtk_tree_store_set (GTK_TREE_STORE (model), &iter, col, tmp_str, -1);
 			g_free (tmp_str);
             col++;
             list = list->next;
         }
 
-        if (etat.csv_skipped_lines [line])
+		if (w_etat->csv_skipped_lines [line])
         {
             gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 0, TRUE, -1);
         }
@@ -1284,71 +1299,13 @@ static gboolean csv_import_update_preview (GtkWidget *assistant)
         line++;
     }
 
+	/* set force date format of widget */
+	utils_widget_import_csv_options_set_combo_order (assistant, w_run->import_format_order);
     csv_import_update_validity_check (assistant);
 
     return FALSE;
 }
 
-/**
- * Callback triggered when separator is changed in the GtkEntry
- * containing it.
- *
- * \param entry		Entry that triggered event.
- * \param position	Position of the change (not used).
- *
- * \return			FALSE
- **/
-static gboolean csv_import_change_separator (GtkEntry *entry,
-											 GtkWidget *assistant)
-{
-    GtkWidget *combobox;
-    gchar *separator;
-    gint index = 0;
-
-	devel_debug (NULL);
-    combobox = g_object_get_data (G_OBJECT(entry), "combobox");
-    separator = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
-
-	if (strlen (separator) > 0)
-    {
-		gchar *contents = NULL;
-		GArray *lines_tab;
-
-        g_object_set_data (G_OBJECT(assistant), "separator", separator);
-		if (etat.csv_separator && strlen (etat.csv_separator) > 0)
-			g_free (etat.csv_separator);
-		etat.csv_separator = separator;
-		contents = g_object_get_data (G_OBJECT(assistant), "contents");
-		if (!contents || strlen (contents) == 0)
-			return FALSE;
-
-		lines_tab = g_object_get_data (G_OBJECT(assistant), "lines_tab");
-		if (lines_tab)
-			csv_import_free_lines_tab (lines_tab);
-
-		lines_tab = csv_import_init_lines_tab (&contents, etat.csv_separator);
-		g_object_set_data (G_OBJECT(assistant), "lines-tab", lines_tab);
-		first_line_with_cols = 0;
-        csv_import_update_preview (assistant);
-    }
-    else
-    {
-		if (etat.csv_separator)
-			g_free (etat.csv_separator);
-        etat.csv_separator = (gchar*)"";
-        g_object_set_data (G_OBJECT(assistant), "separator", NULL);
-    }
-
-    /* Update combobox if we can. */
-	index = utils_widget_csv_separators_combo_update (separator);
-
-    utils_widget_csv_separators_combo_block_unblock (combobox, entry, TRUE);
-    gtk_combo_box_set_active (GTK_COMBO_BOX(combobox), index);
-    utils_widget_csv_separators_combo_block_unblock (combobox, entry, FALSE);
-
-	return FALSE;
-}
-
 /******************************************************************************/
 /* Public functions                                                           */
 /******************************************************************************/
@@ -1425,9 +1382,9 @@ gboolean csv_import_file_by_rule (gint rule,
 		list = gsb_data_import_rule_get_csv_spec_lines_list (rule);
 		while (list)
 		{
-			SpecConfData *spec_conf_data;
+			CsvSpecConfData *spec_conf_data;
 
-			spec_conf_data = (SpecConfData *) list->data;
+			spec_conf_data = (CsvSpecConfData *) list->data;
 			lines_tab = csv_import_button_rule_traite_spec_line (spec_conf_data, lines_tab, index);
 			list = list->next;
 		};
@@ -1449,7 +1406,7 @@ gboolean csv_import_file_by_rule (gint rule,
 
         for (i = 0; csv_fields_config[i] != -1 && list ; i++)
         {
-            struct csv_field *field;
+            struct CsvField *field;
 
 			field = &csv_fields [csv_fields_config[i]];
 			if (field->parse)
@@ -1487,7 +1444,9 @@ gboolean csv_import_file_by_rule (gint rule,
         }
 
         /* g_print (">> Appending new transaction %p\n", ope); */
-        compte->operations_importees = g_slist_append (compte->operations_importees, ope);
+        compte->operations_importees = g_slist_insert_sorted (compte->operations_importees,
+															  ope,
+															  (GCompareFunc) classement_sliste_transactions_par_date);
 
 		index++;
         list = g_array_index (lines_tab, GSList *, index);
@@ -1529,8 +1488,10 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
 	GArray *lines_tab;
     GSList *list;
     gint index = 0;
+	GrisbiWinEtat *w_etat;
 
 	devel_debug (imported->name);
+	w_etat = grisbi_win_get_w_etat ();
 	compte = g_malloc0 (sizeof (struct ImportAccount));
     compte->nom_de_compte = gsb_import_unique_imported_name (_("Imported CSV account"));
     compte->origine = my_strdup ("CSV");
@@ -1554,7 +1515,7 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
 		gchar *csv_fields_str;
 		gint i;
 		CSVImportRule *csv_import_rule;
-		SpecConfData *spec_conf_data;
+		CsvSpecConfData *spec_conf_data;
 
 		csv_import_rule = g_object_get_data (G_OBJECT (assistant), "csv-import-rule");
 		compte->csv_rule_name = csv_import_rule->csv_rule_name;
@@ -1593,7 +1554,7 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
 		lines_list = csv_import_rule->csv_spec_lines_list;
 		if (lines_list)
 		{
-			spec_conf_data = (SpecConfData *) lines_list->data;
+			spec_conf_data = (CsvSpecConfData *) lines_list->data;
 			if (spec_conf_data->csv_spec_conf_used_text)
 			{
 				compte->csv_spec_lines_list = g_slist_copy_deep (lines_list,
@@ -1616,7 +1577,7 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
         gint i;
 
         /* Check if this line was specified as to be skipped earlier. */
-        if (index < CSV_MAX_TOP_LINES && etat.csv_skipped_lines [index])
+        if (index < CSV_MAX_TOP_LINES && w_etat->csv_skipped_lines [index])
         {
             /* g_print ("Skipping line %d\n", index ); */
             index++;
@@ -1635,7 +1596,7 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
 
         for (i = 0; csv_fields_config[i] != -1 && list ; i++)
         {
-            struct csv_field *field;
+            struct CsvField *field;
 
 			field = &csv_fields [csv_fields_config[i]];
 			if (field->parse)
@@ -1658,6 +1619,28 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
 								ope->ope_de_ventilation = 1;
 							}
 						}
+						else if (csv_fields_config[i] == 7)
+						{
+							if (field->parse (ope, list->data))
+							{
+								if (ope->categ && (strncmp (ope->categ, _("Transfer"), strlen (_("Transfer"))) == 0))
+								{
+									ope->transfert = TRUE;
+								}
+							}
+						}
+						else if (csv_fields_config[i] == 8)
+						{
+							if (ope->transfert == TRUE)
+							{
+								g_free (ope->categ);
+								ope->categ = g_strdup (list->data);
+							}
+							else if (!field->parse (ope, list->data))
+							{
+								/* g_print ("%s", "(failed)"); */
+							}
+						}
 						else if (!field->parse (ope, list->data))
 						{
 							/* g_print ("%s", "(failed)"); */
@@ -1673,7 +1656,9 @@ gboolean csv_import_csv_account (GtkWidget *assistant,
         }
 
         /* g_print (">> Appending new transaction %p\n", ope); */
-        compte->operations_importees = g_slist_append (compte->operations_importees, ope);
+        compte->operations_importees = g_slist_insert_sorted (compte->operations_importees,
+															  ope,
+															  (GCompareFunc) classement_sliste_transactions_par_date);
 
 		index++;
         list = g_array_index (lines_tab, GSList *, index);
@@ -1715,12 +1700,8 @@ GtkWidget *import_create_csv_preview_page (GtkWidget *assistant)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, MARGIN_BOX);
     gtk_container_set_border_width (GTK_CONTAINER(vbox), BOX_BORDER_WIDTH);
 
-	/* set choose csv separators */
-    paddingbox = new_paddingbox_with_title (vbox, FALSE, _("Choose CSV separator"));
-	hbox = utils_widget_csv_separators_new (NULL,
-											G_CALLBACK (csv_import_change_separator),
-											assistant);
-    gtk_box_pack_start (GTK_BOX(paddingbox), hbox, FALSE, FALSE, 0);
+	/* set hbox options for csv separator and force dates data */
+	utils_widget_import_csv_options_widget_new (vbox, FALSE, assistant);
 
 	/* set select csv fields */
     paddingbox = new_paddingbox_with_title (vbox, TRUE, _("Select CSV fields"));
@@ -1777,6 +1758,9 @@ gboolean import_enter_csv_preview_page (GtkWidget *assistant)
     gchar *contents;
     gchar *filename = NULL;
     struct ImportFile *imported = NULL;
+	GrisbiWinEtat *w_etat;
+
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* Find first CSV to import. */
     files = gsb_import_import_selected_files (assistant);
@@ -1800,15 +1784,15 @@ gboolean import_enter_csv_preview_page (GtkWidget *assistant)
 	g_object_set_data_full (G_OBJECT(assistant), "contents", contents, g_free);
 
 	/* itialisation de separator */
-	if (etat.csv_separator)
-		g_free (etat.csv_separator);
-	etat.csv_separator = csv_import_guess_separator (contents);
+	if (w_etat->csv_separator)
+		g_free (w_etat->csv_separator);
+	w_etat->csv_separator = csv_import_guess_separator (contents);
 
 	/* on initialise first_line_with_cols */
 	first_line_with_cols = 0;
 
     entry = g_object_get_data (G_OBJECT(assistant), "entry");
-	gtk_entry_set_text (GTK_ENTRY (entry), etat.csv_separator);
+	gtk_entry_set_text (GTK_ENTRY (entry), w_etat->csv_separator);
 
     return FALSE;
 }
@@ -1841,6 +1825,68 @@ GSList *csv_import_get_columns_list	(GtkWidget *assistant)
 	return list;
 }
 
+/**
+ * Callback triggered when separator is changed in the GtkEntry
+ * containing it.
+ *
+ * \param entry		Entry that triggered event.
+ * \param position	Position of the change (not used).
+ *
+ * \return			FALSE
+ **/
+gboolean csv_import_change_separator (GtkEntry *entry,
+									  GtkWidget *assistant)
+{
+    GtkWidget *combobox;
+    gchar *separator;
+    gint index = 0;
+	GrisbiWinEtat *w_etat;
+
+	devel_debug (NULL);
+	w_etat = grisbi_win_get_w_etat ();
+    combobox = g_object_get_data (G_OBJECT(entry), "combobox");
+    separator = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+
+	if (strlen (separator) > 0)
+    {
+		gchar *contents = NULL;
+		GArray *lines_tab;
+
+        g_object_set_data (G_OBJECT(assistant), "separator", separator);
+		if (w_etat->csv_separator && strlen (w_etat->csv_separator) > 0)
+			g_free (w_etat->csv_separator);
+		w_etat->csv_separator = separator;
+		contents = g_object_get_data (G_OBJECT(assistant), "contents");
+		if (!contents || strlen (contents) == 0)
+			return FALSE;
+
+		lines_tab = g_object_get_data (G_OBJECT(assistant), "lines_tab");
+		if (lines_tab)
+			csv_import_free_lines_tab (lines_tab);
+
+		lines_tab = csv_import_init_lines_tab (&contents, w_etat->csv_separator);
+		g_object_set_data (G_OBJECT(assistant), "lines-tab", lines_tab);
+		first_line_with_cols = 0;
+        csv_import_update_preview (assistant);
+    }
+    else
+    {
+		if (w_etat->csv_separator)
+			g_free (w_etat->csv_separator);
+        w_etat->csv_separator = (gchar*)"";
+        g_object_set_data (G_OBJECT(assistant), "separator", NULL);
+    }
+
+    /* Update combobox if we can. */
+	index = utils_widget_csv_separators_combo_update (separator);
+
+    utils_widget_csv_separators_combo_block_unblock (combobox, entry, TRUE);
+    gtk_combo_box_set_active (GTK_COMBO_BOX(combobox), index);
+    utils_widget_csv_separators_combo_block_unblock (combobox, entry, FALSE);
+
+	return FALSE;
+}
+
 /**
  *
  *
