@@ -7,15 +7,9 @@
 #include "import.h"
 /* END_INCLUDE_H */
 
-struct csv_field {
-    const gchar * 	name;
-    gfloat 		alignment;
-    gboolean 	(*validate) (gchar *);
-    gboolean 	(*parse) (struct ImportTransaction *, gchar *);
-    const gchar *		alias;
-};
-
 /* START_DECLARATION */
+gboolean 		csv_import_change_separator			(GtkEntry *entry,
+													 GtkWidget *assistant);
 gboolean 		csv_import_csv_account 				(GtkWidget *assistant,
 													 struct ImportFile *imported);
 gboolean		csv_import_file_by_rule				(gint rule,
