@@ -55,7 +55,6 @@
 #include "help.h"
 #include "import.h"
 #include "navigation.h"
-#include "parametres.h"
 #include "structures.h"
 #include "traitement_variables.h"
 #include "tip.h"
@@ -114,22 +113,25 @@ static gboolean gsb_menu_help_manual (void)
 {
     gchar *lang = _("en");
     gchar *string;
+	GrisbiAppConf *a_conf;
 
-    string = g_build_filename (gsb_dirs_get_help_dir (), lang, "manual.html", NULL);
+	a_conf = (GrisbiAppConf *) grisbi_app_get_a_conf ();
 
-    if (g_file_test (string,
-		      G_FILE_TEST_EXISTS))
+	if (a_conf->display_help)
+		string = g_build_filename (gsb_dirs_get_help_dir (), lang, "manual.pdf", NULL);
+	else
+    	string = g_build_filename (gsb_dirs_get_help_dir (), lang, "manual.html", NULL);
+
+	if (!g_file_test (string, G_FILE_TEST_EXISTS))
     {
-	lance_navigateur_web (string);
-	g_free (string);
+		gchar *str_to_free;
+
+		str_to_free = string;
+		string = gsb_string_remplace_string (str_to_free, "manual.", "grisbi-manuel.");
+		g_free (str_to_free);
     }
-    else
-    {
-	g_free (string);
-	string = g_build_filename (gsb_dirs_get_help_dir (), lang, "grisbi-manuel.html", NULL);
 	lance_navigateur_web (string);
-	g_free (string);
-    }
+	g_free(string);
 
     return FALSE;
 }
@@ -231,10 +233,13 @@ void grisbi_cmd_prefs (GSimpleAction *action,
 					   GVariant *parameter,
 					   gpointer app)
 {
+	gint result;
 	GrisbiPrefs *prefs;
 	GrisbiWin *win;
-	gint result;
+	GrisbiWinRun *w_run;
 
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+	w_run->menu_prefs = TRUE;
 	win = grisbi_app_get_active_window (app);
 	prefs = grisbi_prefs_new (win);
 	grisbi_win_set_prefs_dialog (win, GTK_WIDGET (prefs));
@@ -243,6 +248,7 @@ void grisbi_cmd_prefs (GSimpleAction *action,
 	gtk_widget_show_all (GTK_WIDGET (prefs));
 	result = gtk_dialog_run (GTK_DIALOG (prefs));
 	grisbi_prefs_dialog_response (GTK_DIALOG (prefs), result);
+	w_run->menu_prefs = FALSE;
 }
 
 /* HELP MENU */
@@ -405,7 +411,11 @@ void grisbi_cmd_file_open_direct_menu (GSimpleAction *action,
 	devel_debug (NULL);
 	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
 
-    /* continue only if can close the current file */
+	/* on sort si un fichier est déjà en cours de chargement */
+	if (grisbi_win_status_bar_get_wait_state ())
+		return;
+
+	/* continue only if can close the current file */
     if (w_run->file_is_loading && !gsb_file_close ())
 		return;
 
@@ -443,10 +453,13 @@ void grisbi_cmd_file_save (GSimpleAction *action,
 						   GVariant *parameter,
 						   gpointer app)
 {
+	GrisbiWinRun *w_run;
+
 	/* disable quit. See bug #1969 */
-	run.menu_save = TRUE;
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+	w_run->menu_save = TRUE;
 	gsb_file_save ();
-	run.menu_save = FALSE;
+	w_run->menu_save = FALSE;
 }
 
 /**
@@ -462,9 +475,12 @@ void grisbi_cmd_file_save_as (GSimpleAction *action,
 							  GVariant *parameter,
 							  gpointer app)
 {
-	run.menu_save = TRUE;
+	GrisbiWinRun *w_run;
+
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+	w_run->menu_save = TRUE;
 	gsb_file_save_as ();
-	run.menu_save = FALSE;
+	w_run->menu_save = FALSE;
 }
 
 /**
@@ -756,8 +772,8 @@ void grisbi_cmd_move_to_account_menu (GSimpleAction *action,
 
 		source_account = gsb_gui_navigation_get_current_account ();
 		gsb_transactions_list_move_transaction_to_account_from_menu (source_account, target_account);
-		g_free (tmp_str);
 	}
+	g_free (tmp_str);
 }
 
 /**
@@ -805,10 +821,23 @@ void grisbi_cmd_search_acc (GSimpleAction *action,
 							GVariant *parameter,
 							gpointer app)
 {
-	devel_debug (NULL);
+	gint account_number;
+	gint page_number;
+	gint transaction_number;
 
-	gsb_gui_navigation_select_reports_page ();
-	etats_onglet_create_search_report ();
+	devel_debug (NULL);
+	page_number = gsb_gui_navigation_get_current_page ();
+	if (page_number == GSB_ACCOUNT_PAGE)
+	{
+		account_number = gsb_gui_navigation_get_current_account ();
+		transaction_number = gsb_data_account_get_current_transaction_number (account_number);
+		gsb_transactions_list_search (NULL, GINT_TO_POINTER (transaction_number));
+	}
+	else
+	{
+		gsb_gui_navigation_select_reports_page ();
+		etats_onglet_create_search_report ();
+	}
 }
 
 /* VIEW MENU */
@@ -847,22 +876,24 @@ void grisbi_cmd_show_reconciled_toggle (GSimpleAction *action,
 										GVariant *state,
 										gpointer app)
 {
-    gint current_account;
+	gint current_account;
+	GrisbiWinRun *w_run;
 
-    current_account = gsb_gui_navigation_get_current_account ();
-    if (current_account == -1 || run.equilibrage == 1)
-        return;
+		w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
+		current_account = gsb_gui_navigation_get_current_account ();
+	if (current_account == -1 || w_run->equilibrage == TRUE)
+		return;
 
-    if (gsb_data_account_get_r (current_account))
-    {
-	    gsb_transactions_list_mise_a_jour_affichage_r (FALSE);
-        g_action_change_state (G_ACTION (action), g_variant_new_boolean (FALSE));
-    }
-    else
-    {
-	    gsb_transactions_list_mise_a_jour_affichage_r (TRUE);
-        g_action_change_state (G_ACTION (action), g_variant_new_boolean (TRUE));
-    }
+	if (gsb_data_account_get_r (current_account))
+	{
+		gsb_transactions_list_mise_a_jour_affichage_r (FALSE);
+		g_action_change_state (G_ACTION (action), g_variant_new_boolean (FALSE));
+	}
+	else
+	{
+		gsb_transactions_list_mise_a_jour_affichage_r (TRUE);
+		g_action_change_state (G_ACTION (action), g_variant_new_boolean (TRUE));
+	}
 }
 
 /**
@@ -970,9 +1001,11 @@ void grisbi_cmd_reset_width_col (GSimpleAction *action,
 gboolean gsb_menu_gui_toggle_show_reconciled (void)
 {
     gint current_account;
+	GrisbiWinRun *w_run;
 
+	w_run = (GrisbiWinRun *) grisbi_win_get_w_run ();
     current_account = gsb_gui_navigation_get_current_account ();
-    if (current_account == -1 || run.equilibrage == 1)
+    if (current_account == -1 || w_run->equilibrage == TRUE)
         return FALSE;
 
     if (gsb_data_account_get_r (current_account))
@@ -1182,6 +1215,7 @@ void gsb_menu_set_menus_with_file_sensitive (gboolean sensitive)
         "file-close",
         "new-acc",
         "show-closed-acc",
+		"search-acc",
         NULL
     };
     const gchar **tmp = items;
