@@ -34,6 +34,7 @@
 /*START_INCLUDE*/
 #include "qif.h"
 #include "dialog.h"
+#include "grisbi_win.h"
 #include "gsb_data_account.h"
 #include "gsb_data_archive_store.h"
 #include "gsb_data_category.h"
@@ -82,12 +83,14 @@ extern GSList *liste_comptes_importes_error;
  **/
 static void gsb_qif_free_struct_account (struct ImportAccount *imported_account)
 {
-    g_free (imported_account->origine);
-	g_free (imported_account->real_filename);
-	g_free (imported_account->filename);
-	g_free (imported_account->nom_de_compte);
-
-	g_free (imported_account);
+	if (imported_account)
+	{
+		g_free (imported_account->origine);
+		g_free (imported_account->real_filename);
+		g_free (imported_account->filename);
+		g_free (imported_account->nom_de_compte);
+		g_free (imported_account);
+	}
 }
 
 /**
@@ -447,8 +450,10 @@ static GDate *gsb_qif_get_date (gchar *date_string, gint order)
  **/
 static gboolean qif_traite_champs_n (struct ImportTransaction *imported_transaction)
 {
-    //~ printf ("Champs N = %s champ P = %s\n", imported_transaction->cheque, imported_transaction->tiers);
+	GrisbiWinEtat *w_etat;
 
+	w_etat = grisbi_win_get_w_etat ();
+    //~ printf ("Champs N = %s champ P = %s\n", imported_transaction->cheque, imported_transaction->tiers);
     if (!imported_transaction->cheque)
     {
 		if (strncmp (imported_transaction->tiers, "VIR RECU", 8) == 0)
@@ -462,6 +467,8 @@ static gboolean qif_traite_champs_n (struct ImportTransaction *imported_transact
 				g_free (imported_transaction->cheque);
 				imported_transaction->cheque = tmp_str;
 			}
+			else
+				g_free(tmp_str);
 		}
         return FALSE;
     }
@@ -485,7 +492,7 @@ static gboolean qif_traite_champs_n (struct ImportTransaction *imported_transact
     }
 
     /* Ici on traie le fichier type SG voir si généralisable */
-    if (etat.qif_use_field_extract_method_payment)
+    if (w_etat->qif_use_field_extract_method_payment)
     {
         if (strcmp (imported_transaction->cheque, "Prélvmt") == 0)
         {
@@ -506,6 +513,8 @@ static gboolean qif_traite_champs_n (struct ImportTransaction *imported_transact
                 g_free (imported_transaction->cheque);
                 imported_transaction->cheque = tmp_str;
             }
+			else
+				g_free(tmp_str);
         }
         else if (strcmp (imported_transaction->cheque, "Virement") == 0)
         {
@@ -527,18 +536,20 @@ static gboolean qif_traite_champs_n (struct ImportTransaction *imported_transact
 static gchar *gsb_qif_get_account_name (FILE *qif_file,
 										const gchar *coding_system)
 {
-    gchar *tmp_str;
+    gchar *tmp_str = NULL;
     gchar *name = NULL;
     gint returned_value = 0;
 
     do
     {
+		g_free(tmp_str);
         returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 
         if (tmp_str[0] == 'N')
             name = my_strdup (tmp_str + 1);
     }
-    while (tmp_str[0] != '^' && returned_value != EOF && tmp_str[0] != '!');
+    while (returned_value != EOF && tmp_str[0] != '^' && tmp_str[0] != '!');
+	g_free(tmp_str);
 
     return name;
 }
@@ -604,20 +615,17 @@ static gint gsb_qif_cree_liste_comptes (FILE *qif_file,
 	{
 		do
 		{
-			if (tmp_str
+			if (returned_value != EOF
 			 &&
-			 returned_value != EOF
+			 tmp_str
 			 &&
-			 tmp_str[0] == 'N'
-			 &&
-			 tmp_str[0] != '^'
-			 &&
-			 tmp_str[0] != '!')
+			 tmp_str[0] == 'N')
 			{
 				gchar *name;
 
 				name = g_strdup (tmp_str+1);
 				g_free (tmp_str);
+				tmp_str = NULL;
 
 				/* on regarde si le compte existe déjà */
 				tmp_list = g_slist_find_custom (liste_comptes_importes, name, (GCompareFunc) gsb_qif_name_compare);
@@ -629,9 +637,9 @@ static gint gsb_qif_cree_liste_comptes (FILE *qif_file,
 					returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 					do
 					{
-						if (tmp_str
+						if (returned_value != EOF
 						 &&
-						 returned_value != EOF
+						 tmp_str
 						 &&
 						 tmp_str[0] != '^'
 						 &&
@@ -648,7 +656,7 @@ static gint gsb_qif_cree_liste_comptes (FILE *qif_file,
 						g_free (tmp_str);
 						returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 					}
-					while (tmp_str && tmp_str[0] != '^' && returned_value != EOF && tmp_str[0] != '!');
+					while (returned_value != EOF && tmp_str && tmp_str[0] != '^' && tmp_str[0] != '!');
 
 					liste_comptes_importes = g_slist_append (liste_comptes_importes, imported_account);
 				}
@@ -678,26 +686,34 @@ static gint gsb_qif_cree_liste_comptes (FILE *qif_file,
 			else
 				returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 		}
-		while (tmp_str && returned_value != EOF && tmp_str[0] != '!');
+		while (returned_value != EOF && tmp_str && tmp_str[0] != '!');
 	}
 	//~ printf ("tmp_str en fin de liste = %s returned_value= %d\n", tmp_str, returned_value);
 
     if (returned_value == EOF)
+	{
+		g_free(tmp_str);
 		return EOF;
+	}
     else																	/* tmp_str[0] = '!' */
 	{
 		if (g_ascii_strncasecmp (tmp_str, "!Clear:AutoSwitch", 18) == 0)
 		{
 			returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 			if (returned_value == EOF)
+			{
+				g_free(tmp_str);
 				return EOF;
+			}
 			else if (tmp_str[0] != '!')
+			{
+				g_free(tmp_str);
 				return 1;
+			}
 		}
 
-		if (last_header && strlen (last_header))
-			g_free (last_header);
-		last_header = g_strdup (tmp_str);
+		g_free (last_header);
+		last_header = tmp_str;
 
 		return 0;
 	}
@@ -720,19 +736,21 @@ static gint gsb_qif_recupere_operations_from_account (FILE *qif_file,
     gint returned_value;
     struct ImportTransaction *imported_splitted = NULL;
     struct ImportTransaction *imported_transaction;
+	GrisbiWinEtat *w_etat;
 
-    imported_transaction = g_try_malloc0 (sizeof (struct ImportTransaction));
+	imported_transaction = g_try_malloc0 (sizeof (struct ImportTransaction));
 	if (!imported_transaction)
 		return 0;
 
-    do
-    {
+	w_etat = grisbi_win_get_w_etat ();
+	do
+	{
         returned_value = utils_files_get_utf8_line_from_file (qif_file, &string, coding_system);
 
         /* a transaction never begin with ^ and !*/
-        if (strlen (string)
-         &&
-         returned_value != EOF
+        if (returned_value != EOF
+		 &&
+		 strlen (string)
          &&
          string[0] != '^'
          &&
@@ -778,7 +796,7 @@ static gint gsb_qif_recupere_operations_from_account (FILE *qif_file,
             {
                 imported_transaction->tiers = my_strdup (string + 1);
                 /* ici on appelle la fonction de traitement du champs N qui dépend de P */
-				if (etat.qif_use_field_extract_method_payment)
+				if (w_etat->qif_use_field_extract_method_payment)
                 	qif_traite_champs_n (imported_transaction);
             }
 
@@ -823,6 +841,11 @@ static gint gsb_qif_recupere_operations_from_account (FILE *qif_file,
 						g_free (imported_transaction->tiers);
 					if (imported_transaction->categ)
 						g_free (imported_transaction->categ);
+					imported_transaction->date_tmp = NULL;
+					imported_transaction->notes = NULL;
+					imported_transaction->cheque = NULL;
+					imported_transaction->tiers = NULL;
+					imported_transaction->categ = NULL;
 					imported_transaction->p_r = 0;
 					imported_transaction->montant = null_real;
 
@@ -875,8 +898,8 @@ static gint gsb_qif_recupere_operations_from_account (FILE *qif_file,
                 g_free (new_str);
             }
         }
-    }
-    while (string[0] != '^' && returned_value != EOF && string[0] != '!');
+	}
+    while (returned_value != EOF && string[0] != '^' && string[0] != '!');
 
     /* either we are at the end of a transaction, either at the end of the file */
     /* sometimes we have ^ and EOF, so we need in that case to take the transaction */
@@ -914,22 +937,22 @@ static gint gsb_qif_recupere_operations_from_account (FILE *qif_file,
 																	 imported_transaction);
         }
     }
-
-	if (!imported_transaction->date_tmp)
-	{
+	else
 		g_free (imported_transaction);
-	}
+
     if (returned_value != EOF  && string[0] != '!')
 	{
 		return 1;
 	}
     else if (returned_value == EOF)
+	{
+		g_free(string);
         return EOF;
+	}
     else													/* string[0] = '!' */
     {
-        if (last_header && strlen (last_header))
-            g_free (last_header);
-        last_header = g_strdup (string);
+		g_free (last_header);
+        last_header = string;
 
 		return 0;
 	}
@@ -948,22 +971,19 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
 {
     gchar *tmp_str;
     gint returned_value;
+	GrisbiWinEtat *w_etat;
 
 	devel_debug (NULL);
-
+	w_etat = grisbi_win_get_w_etat ();
 	returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
     do
     {
         /* a category never begin with ^ and !*/
-        if (tmp_str
+        if (returned_value != EOF
+		 &&
+		 tmp_str
          &&
-         returned_value != EOF
-         &&
-         tmp_str[0] == 'N'
-         &&
-         tmp_str[0] != '^'
-         &&
-         tmp_str[0] != '!')
+         tmp_str[0] == 'N')
         {
             gint category_number;
             gint type_category = 1;
@@ -975,9 +995,9 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
 
 			do
             {
-                if (tmp_str
-                 &&
-                 returned_value != EOF
+                if (returned_value != EOF
+				 &&
+				 tmp_str
                  &&
                  tmp_str[0] != '^'
                  &&
@@ -990,14 +1010,14 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
                 }
 				returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 			}
-            while (tmp_str && tmp_str[0] != '^' && returned_value != EOF && tmp_str[0] != '!');
+            while (returned_value != EOF && tmp_str && tmp_str[0] != '^' && tmp_str[0] != '!');
 
             /* get the category and create it if doesn't exist */
             if (tab_str[0])
             {
                 tab_str[0] = g_strstrip (tab_str[0]);
                 category_number = gsb_data_category_get_number_by_name (tab_str[0],
-																		etat.qif_no_import_categories,
+																		w_etat->qif_no_import_categories,
 																		type_category);
 
                 if (tab_str[1])
@@ -1006,7 +1026,7 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
 
                     gsb_data_category_get_sub_category_number_by_name (category_number,
 																	   tab_str[1],
-																	   etat.qif_no_import_categories);
+																	   w_etat->qif_no_import_categories);
                 }
             }
 
@@ -1018,17 +1038,22 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
 
 		returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
     }
-    while (tmp_str && tmp_str[0] != '^' && returned_value != EOF && tmp_str[0] != '!');
+    while (returned_value != EOF && tmp_str && tmp_str[0] != '^' && tmp_str[0] != '!');
 
     if (returned_value != EOF  && tmp_str && tmp_str[0] != '!')		/* tmp_str[0] = '^' */
+	{
+		g_free(tmp_str);
         return 1;
+	}
     else if (returned_value == EOF)
+	{
+		g_free(tmp_str);
         return EOF;
+	}
     else															/* tmp_str[0] = '!' */
     {
-        if (last_header && strlen (last_header))
-            g_free (last_header);
-        last_header = g_strdup (tmp_str);
+		g_free (last_header);
+        last_header = tmp_str;
 
 		return 0;
     }
@@ -1045,7 +1070,7 @@ static gint gsb_qif_recupere_categories (FILE *qif_file,
 static gint gsb_qif_passe_ligne (FILE *qif_file,
 								 const gchar *coding_system)
 {
-    gchar *tmp_str;
+    gchar *tmp_str = NULL;
     gint returned_value = 0;
 
 	devel_debug (NULL);
@@ -1058,19 +1083,23 @@ static gint gsb_qif_passe_ligne (FILE *qif_file,
 
 		do
 		{
+			g_free(tmp_str);
+			tmp_str = NULL;
 			returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, coding_system);
 			//~ printf ("tmp_str = %s returned_value = %d\n", tmp_str, returned_value);
 		}
-		while (returned_value != EOF && tmp_str[0] != '!');
+		while (returned_value != EOF && tmp_str && tmp_str[0] != '!');
 	}
 
     if (returned_value == EOF)
+	{
+		g_free(tmp_str);
         return EOF;
+	}
     else 		/* tmp_str[0] == '!' */
     {
-        if (last_header && strlen (last_header))
-            g_free (last_header);
-        last_header = g_strdup (tmp_str);
+		g_free (last_header);
+        last_header = tmp_str;
 
 		return 0;
     }
@@ -1099,7 +1128,7 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
     gint returned_value = 0;
 	gboolean accounts_liste = FALSE;
 	gboolean premier_compte = TRUE;
-	gboolean no_save_account = FALSE;
+	gboolean save_account = TRUE;
     FILE *qif_file;
 
 	devel_debug (NULL);
@@ -1143,8 +1172,11 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
 						accounts_liste = TRUE;
 						if (premier_compte)
 						{
-							gsb_qif_free_struct_account (imported_account);
-							imported_account = NULL;
+							if (save_account)
+							{
+								gsb_qif_free_struct_account (imported_account);
+								imported_account = NULL;
+							}
 							premier_compte = FALSE;
 							tmp_str = last_header;
 						}
@@ -1165,32 +1197,32 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
 						tmp_list = g_slist_find_custom (liste_comptes_importes,
 														account_name,
 														(GCompareFunc) gsb_qif_name_compare);
+						if (imported_account && save_account)
+						{
+							gsb_qif_free_struct_account (imported_account);
+							imported_account = NULL;
+						}
+
 						if (tmp_list)
 						{
 							imported_account = tmp_list->data;
-							no_save_account = TRUE;
+							save_account = FALSE;
 						}
 						else
 						{
 							imported_account = gsb_qif_init_struct_account (account_name, imported->name);
-							g_free (account_name);
 						}
 					}
 					else
 					{
 						/* create and fill the new account */
 						if (premier_compte)
-						{
-							gsb_qif_free_struct_account (imported_account);
-							imported_account = NULL;
 							premier_compte = FALSE;
-						}
-						else if (name_preced)
+						if (save_account)
 							gsb_qif_free_struct_account (imported_account);
 						imported_account = gsb_qif_init_struct_account (account_name, imported->name);
-
-						g_free (account_name);
 					}
+					g_free (account_name);
 					name_preced = TRUE;
 					returned_value = utils_files_get_utf8_line_from_file (qif_file, &tmp_str, imported->coding_system);
 				}
@@ -1235,16 +1267,13 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
 					{
 						if (name_preced == FALSE)
 						{
-							if (premier_compte)
-							{
+							if (save_account)
 								gsb_qif_free_struct_account (imported_account);
-								imported_account = NULL;
-							}
 
 							/* create and fill the new account */
 							imported_account = gsb_qif_init_struct_account (_("Imported QIF account"), imported->name);
 							premier_compte = FALSE;
-							no_save_account = FALSE;
+							save_account = TRUE;
 						}
 
 						if (account_type == 6)
@@ -1282,12 +1311,14 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
 
         if (returned_value == EOF)
         {
+			g_free(tmp_str);
             if (premier_compte)
 			{
 				if (imported->import_categories)
 				{
 					/* On a juste importé un fichier de catégories */
-					gsb_qif_free_struct_account (imported_account);
+					if (save_account)
+						gsb_qif_free_struct_account (imported_account);
 					fclose (qif_file);
 
 					return TRUE;
@@ -1305,7 +1336,7 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
             else
             {
                 /* we have at least saved an account before, ok, enough for me */
-				if (imported_account)
+				if (imported_account && save_account)
 					gsb_qif_free_struct_account (imported_account);
                 fclose (qif_file);
 
@@ -1325,75 +1356,80 @@ gboolean recuperation_donnees_qif (GtkWidget *assistant,
         /* continue untill the end of the file or a change of account */
         while (returned_value != EOF && returned_value != 0);
 
-        /* first, we need to check if the first transaction is an opening balance
-         * or a normal transaction
-         * update : money sometimes translate Opening balance... */
-		if (imported_account->operations_importees)
+		if (imported_account)
 		{
-			if (g_slist_length (imported_account->operations_importees) > 0)
+			/* first, we need to check if the first transaction is an opening balance
+			 * or a normal transaction
+			 * update : money sometimes translate Opening balance... */
+			if (imported_account->operations_importees)
 			{
-				imported_transaction = imported_account->operations_importees->data;
-				if (imported_transaction->tiers
-				 &&
-				 (!g_ascii_strncasecmp (imported_transaction->tiers, "Opening Balance", 15)
-				 ||
-				 !g_ascii_strcasecmp (imported_transaction->tiers, _("Opening Balance"))))
+				if (g_slist_length (imported_account->operations_importees) > 0)
 				{
-					/* ok, we are on an opening balance, we transfer the first transaction
-					 * to the initial datas of the account */
-
-					/* get the initial amount */
-					imported_account->solde = imported_transaction->montant;
-
-					/* get the name of account */
-					if (!account_name)
+					imported_transaction = imported_account->operations_importees->data;
+					if (imported_transaction->tiers
+							&&
+							(!g_ascii_strncasecmp (imported_transaction->tiers, "Opening Balance", 15)
+							 ||
+							 !g_ascii_strcasecmp (imported_transaction->tiers, _("Opening Balance"))))
 					{
-						tmp_str = my_strdelimit (imported_transaction->dest_account_name, "[]", "");
-						imported_account->nom_de_compte = gsb_import_unique_imported_name (tmp_str);
+						/* ok, we are on an opening balance, we transfer the first transaction
+						 * to the initial datas of the account */
 
-						g_free (tmp_str);
-						tmp_str = NULL;		/* remove Memory error	Use-after-free */
+						/* get the initial amount */
+						imported_account->solde = imported_transaction->montant;
+
+						/* get the name of account */
+						if (!account_name)
+						{
+							tmp_str = my_strdelimit (imported_transaction->dest_account_name, "[]", "");
+							imported_account->nom_de_compte = gsb_import_unique_imported_name (tmp_str);
+
+							g_free (tmp_str);
+							tmp_str = NULL;		/* remove Memory error	Use-after-free */
+						}
+
+						/* get the date of the file */
+						imported_account->date_solde_qif = my_strdup (imported_transaction->date_tmp);
+
+						/* now, we can remove the first imported transaction */
+						imported_account->operations_importees = g_slist_remove (imported_account->operations_importees,
+								imported_transaction);
+						g_free (imported_transaction);
 					}
+					/* now we need to transform the dates of transaction into gdate */
 
-					/* get the date of the file */
-					imported_account->date_solde_qif = my_strdup (imported_transaction->date_tmp);
-
-					/* now, we can remove the first imported transaction */
-					imported_account->operations_importees = g_slist_remove (imported_account->operations_importees,
-												imported_transaction);
-					g_free (imported_transaction);
+					/* try to understand the order */
+					order = gsb_qif_get_date_order (imported_account->operations_importees);
+					if (order == -1)
+						dialogue_error (_("Grisbi couldn't determine the format of the date into the qif file.\n"
+									"Please contact the Grisbi team (devel@listes.grisbi.org) to find "
+									"the problem.\nFor now, all the dates will be imported as 01.01.2000"));
 				}
-				/* now we need to transform the dates of transaction into gdate */
-
-				/* try to understand the order */
-				order = gsb_qif_get_date_order (imported_account->operations_importees);
-				if (order == -1)
-					dialogue_error (_("Grisbi couldn't determine the format of the date into the qif file.\n"
-									  "Please contact the Grisbi team (devel@listes.grisbi.org) to find "
-									  "the problem.\nFor now, all the dates will be imported as 01.01.2000"));
 			}
+
+			tmp_list = imported_account->operations_importees;
+			while (tmp_list)
+			{
+				imported_transaction = tmp_list->data;
+				if (order == -1)
+					/* we didn't find the order */
+					imported_transaction->date = g_date_new_dmy (1,1,2000);
+				else
+					imported_transaction->date = gsb_qif_get_date (imported_transaction->date_tmp, order);
+
+				tmp_list = tmp_list->next;
+			}
+
+			/* set the date of the qif file */
+			if (imported_account->date_solde_qif)
+				imported_account->date_fin = gsb_qif_get_date (imported_account->date_solde_qif, order);
+
+			/* add that account to the others */
+			if (save_account)
+				liste_comptes_importes = g_slist_append (liste_comptes_importes, imported_account);
 		}
-
-		tmp_list = imported_account->operations_importees;
-        while (tmp_list)
-        {
-            imported_transaction = tmp_list->data;
-            if (order == -1)
-                /* we didn't find the order */
-                imported_transaction->date = g_date_new_dmy (1,1,2000);
-            else
-                imported_transaction->date = gsb_qif_get_date (imported_transaction->date_tmp, order);
-
-            tmp_list = tmp_list->next;
-        }
-
-        /* set the date of the qif file */
-        if (imported_account->date_solde_qif)
-            imported_account->date_fin = gsb_qif_get_date (imported_account->date_solde_qif, order);
-
-        /* add that account to the others */
-		if (!no_save_account)
-        	liste_comptes_importes = g_slist_append (liste_comptes_importes, imported_account);
+		else
+			alert_debug("Wrong format\n");
     }
     /* go to the next account */
     while (returned_value != EOF);
@@ -1448,6 +1484,7 @@ gboolean gsb_qif_export_archive (const gchar *filename,
 				name_list = g_slist_append (name_list, new_filename);
 			else
 				error_return = 1;
+			g_free(new_filename);
 		}
 		tmp_list = tmp_list->next;
     }
@@ -1513,6 +1550,7 @@ gboolean qif_export (const gchar *filename,
     gint beginning;
     gint floating_point;
 	gint payment_number;
+	GrisbiWinEtat *w_etat;
 
     if (!gsb_file_util_test_overwrite (filename))
 		return FALSE;
@@ -1526,6 +1564,8 @@ gboolean qif_export (const gchar *filename,
 		return FALSE;
     }
 
+	w_etat = grisbi_win_get_w_etat ();
+
     /* get the floating point of the currency of the amount,
      * ie the number of digits after the . */
     floating_point = gsb_data_currency_get_floating_point (gsb_data_account_get_currency (account_nb));
@@ -1573,7 +1613,7 @@ gboolean qif_export (const gchar *filename,
 			{
 				/* this is the beginning of the qif file, we set some beginnings things */
 				date = gsb_data_transaction_get_date (transaction_number_tmp);
-				if (etat.export_force_US_dates)
+				if (w_etat->export_force_US_dates)
 				{
 					tmp_str = gsb_format_gdate_safe (date);
 					fprintf (fichier_qif,"D%s\n", tmp_str);
@@ -1589,7 +1629,7 @@ gboolean qif_export (const gchar *filename,
 				}
 
 				/* met le solde initial */
-				if (etat.export_force_US_numbers)
+				if (w_etat->export_force_US_numbers)
 				{
 					tmp_str = utils_real_get_string_intl (gsb_data_account_get_init_balance (account_nb, -1));
 				}
@@ -1615,7 +1655,7 @@ gboolean qif_export (const gchar *filename,
 			{
 				/* met la date */
 				date = gsb_data_transaction_get_date (transaction_number_tmp);
-				if (etat.export_force_US_dates)
+				if (w_etat->export_force_US_dates)
 				{
 					tmp_str = gsb_format_gdate_safe (date);
 					fprintf (fichier_qif,"D%s\n", tmp_str);
@@ -1650,7 +1690,7 @@ gboolean qif_export (const gchar *filename,
 							 gsb_data_transaction_get_notes (transaction_number_tmp));
 
 				/* met le montant, transforme la devise si necessaire */
-				if (etat.export_force_US_numbers)
+				if (w_etat->export_force_US_numbers)
 				{
 					tmp_str = utils_real_get_string_intl (gsb_data_transaction_get_adjusted_amount (transaction_number_tmp, floating_point));
 				}
@@ -1728,23 +1768,23 @@ gboolean qif_export (const gchar *filename,
 								/* it's a category : sub-category */
 								if (!mother_transaction_category_written)
 								{
+									tmp_str = gsb_data_category_get_name (gsb_data_transaction_get_category_number
+																		  (transaction_number_tmp_2),
+																		  gsb_data_transaction_get_sub_category_number
+																		  (transaction_number_tmp_2),
+																		  _("No category defined"));
 
-									fprintf (fichier_qif,
-											 "L%s\n",
-											 gsb_data_category_get_name (gsb_data_transaction_get_category_number
-																		 (transaction_number_tmp_2),
-																		 gsb_data_transaction_get_sub_category_number
-																		 (transaction_number_tmp_2),
-																		 _("No category defined")));
+									fprintf (fichier_qif, "L%s\n", tmp_str);
+									g_free(tmp_str);
 									mother_transaction_category_written = 1;
 								}
-								fprintf (fichier_qif,
-										 "S%s\n",
-										 gsb_data_category_get_name (gsb_data_transaction_get_category_number
-																	 (transaction_number_tmp_2),
-																	 gsb_data_transaction_get_sub_category_number
-																	 (transaction_number_tmp_2),
-																	 _("No category defined")));
+								tmp_str = gsb_data_category_get_name (gsb_data_transaction_get_category_number
+																	  (transaction_number_tmp_2),
+																	  gsb_data_transaction_get_sub_category_number
+																	  (transaction_number_tmp_2),
+																	  _("No category defined"));
+								fprintf (fichier_qif, "S%s\n", tmp_str);
+								g_free(tmp_str);
 							}
 
 							/* set the notes of the split child */
@@ -1754,7 +1794,7 @@ gboolean qif_export (const gchar *filename,
 									 gsb_data_transaction_get_notes (transaction_number_tmp_2));
 
 							/* set the amount of the split child */
-							if (etat.export_force_US_numbers)
+							if (w_etat->export_force_US_numbers)
 							{
 								tmp_str = utils_real_get_string_intl (gsb_data_transaction_get_adjusted_amount (transaction_number_tmp_2, floating_point));
 							}
@@ -1785,13 +1825,15 @@ gboolean qif_export (const gchar *filename,
 					}
 					else
 					{
+						gchar *str = gsb_data_category_get_name (gsb_data_transaction_get_category_number
+																 (transaction_number_tmp),
+															  gsb_data_transaction_get_sub_category_number (transaction_number_tmp),
+																 FALSE);
 						/* it's a normal category */
 						fprintf (fichier_qif,
 								 "L%s\n",
-								 gsb_data_category_get_name (gsb_data_transaction_get_category_number
-															 (transaction_number_tmp),
-															 gsb_data_transaction_get_sub_category_number (transaction_number_tmp),
-															 FALSE));
+								 str);
+						g_free(str);
 					}
 				}
 				fprintf (fichier_qif, "^\n");
@@ -1805,7 +1847,7 @@ gboolean qif_export (const gchar *filename,
 		/* there is no transaction in the account, so do the opening of the account, bug no date */
 		/* met le solde initial */
 
-		if (etat.export_force_US_numbers)
+		if (w_etat->export_force_US_numbers)
 		{
 			tmp_str = utils_real_get_string_intl (gsb_data_account_get_init_balance (account_nb, -1));
 		}
