@@ -11,7 +11,7 @@
 /* the VERSION_FICHIER is in fact the lowest version which can be used to open the */
 /* file, so each time we make an incompatibility issue, VERSION_FICHIER must be set */
 /* to VERSION_GRISBI */
-#define VERSION_FICHIER         "1.2.1"
+#define VERSION_FICHIER         "2.0.0"
 #define OLD_VERSION_FICHIER		"0.6.0"
 
 #define VERSION_FICHIER_ETAT    "0.6.0"
@@ -58,16 +58,18 @@
 
 /* width for widget */
 #define BOX_BORDER_WIDTH		10
-#define ENTRY_MIN_WIDTH_1		100
+#define ENTRY_MIN_WIDTH			100
+#define EXPANDER_LABEL_GAP		40				/* ecart negatif pour la largeur du label de l'expander */
 #define FORM_COURT_WIDTH		120				/* largeur minimale demandée pour les champs courts du formulaire */
 #define FORM_LONG_WIDTH			200				/* largeur minimale demandée pour les champs longs du formulaire */
 
 /* constants for Preferences */
-#define PREFS_PANED_MIN_WIDTH	235				/* Largeur Min du panel gauche des preferences */
-#define PREFS_WIN_MIN_HEIGHT	605				/* Hauteur Min de la fenetre des preferences */
-#define PREFS_WIN_MIN_WIDTH		910				/* Largeur Min de la fenetre des preferences */
-#define SW_MAX_CONTENT_WIDTH	600				/* Since Gtk-3.22 */
-#define SW_MIN_HEIGHT			150
+#define PREFS_PANED_MIN_WIDTH		240			/* Largeur Min du panel gauche des preferences */
+#define PREFS_WIN_MIN_HEIGHT		605			/* Hauteur Min de la fenetre des preferences */
+#define PREFS_WIN_MIN_WIDTH_LOW		905			/* Largeur Min de la fenetre des preferences basse resolution */
+#define PREFS_WIN_MIN_WIDTH_HIGH	1050		/* Largeur Min de la fenetre des preferences basse resolution */
+#define SW_MAX_CONTENT_WIDTH		600			/* Since Gtk-3.22 */
+#define SW_MIN_HEIGHT				150
 
 /* used for gtk_tree_view_column_set_alignment() */
 #define COLUMN_LEFT				0.0
@@ -98,9 +100,6 @@
 #define TRANSACTION_LIST_ROWS_NB 		4		/* definition of the number of max rows for a line, for now limit to 4 */
 
 /*START_EXTERN*/
-/* variables initialisées lors de l'exécution de grisbi PROVISOIRE */
-extern struct _GrisbiWinRun run;				/* declared in grisbi_win.c */
-extern struct _GrisbiWinEtat etat;				/* declared in grisbi_win.c */
 /*END_EXTERN*/
 
 /******************************************************************************/
@@ -123,6 +122,7 @@ struct _GrisbiWinEtat
 	/* files and backup part */
 	gint 		crypt_file;									/* TRUE if we want to crypt the file */
     gint 		fichier_deja_ouvert;						/* à un si lors de l'ouverture, le fichier semblait déjà ouvert */
+	gboolean	use_icons_file_dir;							/* TRUE = icons in accounts file directory */
 
     /* devises pour les catégories, imputations budgétaires et les tiers */
     gint		no_devise_totaux_categ;
@@ -203,17 +203,13 @@ struct _GrisbiWinEtat
     gint		bet_index_duree;
     gdouble		bet_frais;
     gint		bet_type_taux;
-
-    /* largeur des colonnes */
-    gchar *		transaction_column_width;
-    gchar *		scheduler_column_width;
 };
 
 /* structure conf variables configured by gsettings or grisbi.conf */
 struct _GrisbiAppConf
 {
 /* root part*/
-    gint        first_use;                                  /* première utilisation ou réinitialisation de grisbi */
+    gboolean	first_use;                                  /* TRUE = première utilisation de grisbi */
 
 /* backup part */
     gboolean    compress_backup;                            /* TRUE if we want to compress the backup */
@@ -226,8 +222,9 @@ struct _GrisbiAppConf
 	guint		remove_backup_months;						/* Number of months before removing backup files */
 
 /* display part */
-    gint        display_window_title;                       /* selection du titre principal de grisbi */
-    gint		display_toolbar;                            /* Display mode of toolbar. */
+	gint		display_help;								/* affiche l'aide dans le navigateur ou dans le visonneur pdf */
+    gint		display_toolbar;                            /* Display mode of toolbar: GtkToolbarStyle */
+    gint        display_window_title;                       /* selection du titre principal de grisbi 1,2 ou 3*/
     gboolean    formulaire_toujours_affiche;                /* TRUE formulaire toujours affiché */
     gboolean    group_partial_balance_under_accounts;       /* TRUE = in home page group the partial balance with accounts */
     gboolean    show_headings_bar;                          /* Show headings bar or not. */
@@ -235,7 +232,7 @@ struct _GrisbiAppConf
 
 /* files part */
     gboolean    compress_file;                              /* TRUE if we want to compress the Grisbi file */
-    gint        dernier_fichier_auto;                       /* chargement du dernier fichier utilisé */
+    gboolean	dernier_fichier_auto;                       /* chargement du dernier fichier utilisé */
     gboolean    force_enregistrement;                       /* à un si on force l'enregistrement */
     gchar *     last_open_file;                             /* dernier fichier ouvert */
     gint        nb_max_derniers_fichiers_ouverts;           /* contient le nb max que peut contenir nb_derniers_fichiers_ouverts */
@@ -250,13 +247,13 @@ struct _GrisbiAppConf
     gint        max_non_archived_transactions_for_check;    /* the max number of transaction before grisbi warm at the opening */
 
 /* form part*/
-    gboolean    affichage_exercice_automatique;             /* automatic fyear :0 to set according to the date, 1 according to value date */
-    gboolean    automatic_completion_payee;                 /* 1 pour autoriser la completion automatique des opérations */
-    gboolean    automatic_erase_credit_debit;               /* 1 pour effacer les champs crédit et débit */
-    gboolean    automatic_recover_splits;                   /* 1 pour recréer automatiquement les sous opérations */
+    gboolean    affichage_exercice_automatique;             /* automatic fyear :FALSE = according to the date, TRUE = according to value date */
+    gboolean    automatic_completion_payee;                 /* TRUE pour autoriser la completion automatique des opérations */
+    gboolean    automatic_erase_credit_debit;               /* TRUE pour effacer les champs crédit et débit */
+    gboolean    automatic_recover_splits;                   /* TRUE pour recréer automatiquement les sous opérations */
 	gint		completion_minimum_key_length;				/* Minimum length of the search key in characters */
     gboolean    form_enter_key;								/* si TRUE, la touche entrée finit l'opération */
-	gboolean	form_validate_split;						/* 0 select a new transaction, 1 select the mother transaction */
+	gboolean	form_validate_split;						/* FALSE select a new transaction, TRUE select the mother transaction */
     gint        fyear_combobox_sort_order;                  /* fyear combobox type sort, GTK_SORT_ASCENDING by default */
     gboolean    limit_completion_to_current_account;        /* Limit payee completion to current account or do a full search. */
 
@@ -267,10 +264,9 @@ struct _GrisbiAppConf
 	gchar *		language_chosen;							/* choix de la langue : NULL par défaut = langue système */
 	gchar *		current_theme;
 	gint		force_type_theme;							/* 0 = auto, 1 = standard 2 = dark theme 3 = light theme */
-	gint		use_type_theme;								/* 1 = standard 2 = dark theme 3 = light theme */
 
     /* Home page */
-    gint        pluriel_final;                              /* 0 = finals 1 = finaux */
+    gboolean	pluriel_final;                              /* FALSE = finals TRUE = finaux */
 
     /* variables for the list of categories */
     gint        metatree_action_2button_press;              /* 0 default gtk, 1 edit_function, 2 manage division if possible */
@@ -291,13 +287,14 @@ struct _GrisbiAppConf
     gboolean    maximize_screen;                            /* TRUE to maximize screen, 0 else */
 
 /* panel part */
-    gboolean 	active_scrolling_left_pane;                 /* active mouse scrolling in the left_pane. */
+    gboolean 	active_scrolling_left_pane;                 /* TRUE active mouse scrolling in the left_pane. */
     gint        panel_width;                                /* navigation paned width */
 
 /* prefs part */
-	gboolean	prefs_archives_sort_order;					/* archive sort order, GTK_SORT_ASCENDING by default */
-    gboolean	prefs_fyear_sort_order;                     /* fyear type sort, GTK_SORT_ASCENDING by default */
+	gint		prefs_archives_sort_order;					/* archive sort order, GTK_SORT_ASCENDING by default */
+    gint		prefs_fyear_sort_order;						/* fyear type sort, GTK_SORT_ASCENDING by default */
 	gint		prefs_height;								/* preferences height */
+	gint		prefs_notebook_width;						/* preferences paned width */
 	gint		prefs_panel_width;							/* preferences paned width */
     gint        prefs_width;                                /* preferences width */
 
@@ -306,17 +303,20 @@ struct _GrisbiAppConf
     gboolean    execute_scheduled_of_month;                 /* warn/execute scheduled at expiration (FALSE) or of the month (TRUE) */
 	gboolean	select_scheduled_in_list;					/* TRUE = select last scheduled in list TRUE by default */
 	gint		nb_days_before_scheduled;					/* nombre de jours avant relance des opérations planifiées */
-	gboolean	scheduler_set_fixed_day;					/* Si coché le nombre est considéré comme un jour fixe */
+	gboolean	scheduler_set_fixed_day;					/* Si TRUE le nombre est considéré comme un jour fixe */
 	gint		scheduler_fixed_day;
 
-    /* Tips */
+/* Tips */
     gint        last_tip;
     gboolean    show_tip;
 
 	/* NOT SAVED */
+	/* general part */
+	gint		use_type_theme;								/* 1 = standard 2 = dark theme 3 = light theme */
+
 	/* CSS data */
 	gint		prefs_change_css_data;						/* compteur de modification d'une règle CSS */
-	gboolean	use_css_local_file;							/* TRUE si utilisation du fichier css local NOT SAVED*/
+	gboolean	use_css_local_file;							/* TRUE si utilisation du fichier css local */
 };
 
 /* structure run
@@ -346,7 +346,7 @@ struct _GrisbiWinRun
     gboolean	menu_save;
 
     /* reconciliation */
-    gint		equilibrage;
+    gboolean	equilibrage;
     gint		reconcile_account_number;					/* Save the last reconciliation try: account */
     gchar *		reconcile_final_balance;					/* final balance amount */
     GDate *		reconcile_new_date;							/* new date */
@@ -375,6 +375,7 @@ struct _GrisbiWinRun
 	gboolean	prefs_expand_tree;							/* memorise le choix du bouton expand collapse du treeview des preferences */
 	guint		prefs_import_tab;							/* mémorise l'onglet import sélectionné */
 	gchar *		prefs_selected_row;							/* memorise l'onglet selectionné du treeview des preferences */
+    gboolean	menu_prefs;
 
 	/* Reports */
 	gboolean	no_show_prefs;								/* si VRAI = ne pas montrer les préférences de l'état */
@@ -386,6 +387,10 @@ struct _GrisbiWinRun
 	gint		display_two_lines;			/* 1-2, 1-3, "1-4 */
 	gint		display_three_lines;		/* 1-2-3, 1-2-4, 1-3-4 */
 
+	/* import fichier CSV */
+	gboolean	import_force_date;			/* force le choix du format et de la colonne date du fichier importé */
+	gint		import_format_order;		/* set index of combo */
+	gchar *		import_format_date;
 };
 
 /** Contain pre-defined CSV separators */
@@ -403,7 +408,6 @@ typedef enum	_CustomModelOpeColumns	CustomModelOpeColumns;
 typedef enum 	_GsbTransactionType		GsbTransactionType;
 typedef enum 	_GsbTitleType	 		GsbTitleType;
 typedef enum 	_MetatreeContent		MetatreeContent;
-typedef enum 	_SettingsSchema 		SettingsSchema;
 typedef enum	_TransactionsField		TransactionsField;
 
 /* définition du titre de grisbi */
@@ -477,23 +481,6 @@ enum _GsbTransactionType
   };
 
 
-enum _SettingsSchema
-{
-    SETTINGS_ROOT = 0,
-    SETTINGS_FILES_BACKUP,
-    SETTINGS_DISPLAY,
-    SETTINGS_FILES_FILE,
-    SETTINGS_FORM,
-    SETTINGS_GENERAL,
-    SETTINGS_GEOMETRY,
-    SETTINGS_MESSAGES_DELETE,
-    SETTINGS_MESSAGES_TIPS,
-    SETTINGS_MESSAGES_WARNINGS,
-    SETTINGS_PANEL,
-    SETTINGS_PREFS,
-    SETTINGS_SCHEDULED
-};
-
 enum FormatDateOrder
 {
     ORDER_DD_MM_YY = 0,
