@@ -105,6 +105,41 @@ enum {
 /******************************************************************************/
 /* Private functions                                                          */
 /******************************************************************************/
+static gboolean payees_search_equal_function (GtkTreeModel *model,
+											  gint column,
+											  const gchar *key,
+											  GtkTreeIter *iter,
+											  gpointer search_data)
+{
+	gboolean ret = TRUE;
+	gchar *payee_name;
+
+	gtk_tree_model_get (model, iter, column, &payee_name, -1);
+	if (payee_name)
+	{
+		GrisbiWinEtat *w_etat;
+		w_etat = grisbi_win_get_w_etat ();
+
+		if (w_etat->combofix_case_sensitive)
+		{
+			if (g_strstr_len (payee_name, -1, key))
+				ret = FALSE;
+		}
+		else
+		{
+			/* case insensitive search, so convert to UPPER case first */
+			gchar * payee_name_u = g_utf8_strup(payee_name, -1);
+			gchar * key_u = g_utf8_strup(key, -1);
+			if (g_strstr_len (payee_name_u, -1, key_u))
+				ret = FALSE;
+			g_free(payee_name_u);
+			g_free(key_u);
+		}
+	}
+
+	return ret;
+}
+
 /**
  *
  *
@@ -154,6 +189,8 @@ static void payee_tree_update_transactions (GtkTreeModel *model,
 static gboolean edit_payee (GtkTreeView * view)
 {
     GtkWidget * dialog, *paddingbox, *table, *label, *entry_name;
+	GtkWidget *button_cancel;
+	GtkWidget *button_apply;
 	GtkWidget *search_entry;
     GtkWidget *check_option_1;
     GtkWidget *check_option_2;
@@ -190,10 +227,17 @@ static gboolean edit_payee (GtkTreeView * view)
     dialog = gtk_dialog_new_with_buttons (title,
 										  GTK_WINDOW (grisbi_app_get_active_window (NULL)),
 										  GTK_DIALOG_MODAL,
-										  "gtk-cancel", GTK_RESPONSE_NO,
-										  "gtk-apply", GTK_RESPONSE_OK,
+										  NULL, NULL,
 										  NULL);
 
+	button_cancel = gtk_button_new_with_label (_("Cancel"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	gtk_widget_set_can_default (button_cancel, TRUE);
+
+	button_apply = gtk_button_new_with_label (_("Apply"));
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_apply, GTK_RESPONSE_APPLY);
+	gtk_widget_set_can_default (button_apply, TRUE);
+
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
@@ -259,7 +303,7 @@ static gboolean edit_payee (GtkTreeView * view)
 
     while (1)
     {
-        if (gtk_dialog_run (GTK_DIALOG(dialog)) != GTK_RESPONSE_OK)
+        if (gtk_dialog_run (GTK_DIALOG(dialog)) != GTK_RESPONSE_APPLY)
         {
             sortie_edit_payee = TRUE;
             gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -499,13 +543,9 @@ static gboolean popup_payee_view_mode_menu (GtkWidget * button)
 
     gtk_widget_show_all (menu);
 
-#if GTK_CHECK_VERSION (3,22,0)
 	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
-#else
-    gtk_menu_popup (GTK_MENU(menu), NULL, button, set_popup_position, button, 1,
-					gtk_get_current_event_time());
-#endif
-    return FALSE;
+
+	return FALSE;
 }
 
 /**
@@ -736,17 +776,25 @@ GtkWidget *payees_create_list (void)
     /* Make amount column */
     cell = gtk_cell_renderer_text_new ();
 	gtk_cell_renderer_set_padding (GTK_CELL_RENDERER (cell), MARGIN_BOX, 0);
-	column = gtk_tree_view_column_new_with_attributes (_("Amount"), cell,
-						       "text", META_TREE_BALANCE_COLUMN,
-						       "weight", META_TREE_FONT_COLUMN,
-						       "xalign", META_TREE_XALIGN_COLUMN,
-                               "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
-						       NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Amount"),
+													   cell,
+													   "text", META_TREE_BALANCE_COLUMN,
+													   "weight", META_TREE_FONT_COLUMN,
+													   "xalign", META_TREE_XALIGN_COLUMN,
+													   "cell-background-rgba", META_TREE_BACKGROUND_COLOR,
+													   NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (payee_tree), GTK_TREE_VIEW_COLUMN (column));
     gtk_tree_view_column_set_alignment (column, COLUMN_RIGHT);
     gtk_container_add (GTK_CONTAINER (scroll_window), payee_tree);
     gtk_widget_show (payee_tree);
 
+	/* set search data fixes bug 2264 */
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (payee_tree), 0);
+	gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (payee_tree),
+										 (GtkTreeViewSearchEqualFunc) payees_search_equal_function,
+										 NULL,
+										 NULL);
+
     /* Connect to signals */
     g_signal_connect (G_OBJECT (payee_tree),
                       "row-collapsed",
@@ -1239,7 +1287,7 @@ static GtkWidget *gsb_assistant_payees_page_2 (GtkWidget *assistant)
 
     combo = gtk_combofix_new_with_properties (tmp_list,
 											  TRUE,
-											  etat.combofix_case_sensitive,
+											  w_etat->combofix_case_sensitive,
 											  FALSE,
 											  METATREE_PAYEE);
 	gsb_data_payee_free_name_and_report_list (tmp_list);
