@@ -377,18 +377,16 @@ static void widget_import_asso_add_button_clicked (GtkWidget *button,
 													   WidgetImportAsso *page)
 {
 	gchar *hint;
-	gchar *tmp_markup_str;
 	WidgetImportAssoPrivate *priv;
 
 	devel_debug (NULL);
 	priv = widget_import_asso_get_instance_private (page);
 
 	hint = g_strdup (_("You are creating a new payee with a rule"));
-	tmp_markup_str = g_markup_printf_escaped ("<span size=\"larger\" weight=\"bold\">%s</span>\n\n", hint);
 	if (dialogue_yes_no (_("If you continue, you will use the payee management module to create "
 						   "a new third party and its rule.\n"
 						   "Continue anyway?"),
-						 tmp_markup_str,
+						 hint,
 						 GTK_RESPONSE_YES))
 	{
 		GtkTreeModel *model;
@@ -415,7 +413,6 @@ static void widget_import_asso_add_button_clicked (GtkWidget *button,
 		widget_import_asso_select_row (priv->treeview_import_asso, model, payee_number);
 	}
 	g_free (hint);
-	g_free (tmp_markup_str);
 }
 
 /**
@@ -672,7 +669,6 @@ static void widget_import_asso_setup_treeview_asso (WidgetImportAsso *page)
 
     /* create the treeview */
 	gtk_tree_view_set_model (GTK_TREE_VIEW (priv->treeview_import_asso), GTK_TREE_MODEL (list_store));
-    g_object_unref (list_store);
 
 	/* set the payee name column */
     cell = gtk_cell_renderer_text_new ();
@@ -701,6 +697,7 @@ static void widget_import_asso_setup_treeview_asso (WidgetImportAsso *page)
 
 	/* fill the list */
     widget_import_asso_fill_model (list_store);
+	g_object_unref (list_store);
 
     utils_set_list_store_background_color (priv->treeview_import_asso, ASSO_BACKGROUND_COLOR);
 
@@ -728,11 +725,13 @@ static void widget_import_asso_setup_import_asso_page (WidgetImportAsso *page)
 {
 	GtkWidget *entry;
 	GSList *tmp_list;
+	GrisbiWinEtat *w_etat;
 	GrisbiWinRun *w_run;
 	WidgetImportAssoPrivate *priv;
 
 	devel_debug (NULL);
 	priv = widget_import_asso_get_instance_private (page);
+	w_etat = grisbi_win_get_w_etat ();
 	w_run = grisbi_win_get_w_run ();
 
 	/* set sensitive button_import_asso_remove */
@@ -741,7 +740,7 @@ static void widget_import_asso_setup_import_asso_page (WidgetImportAsso *page)
 	/* Create entry liste des tiers */
 	tmp_list = gsb_data_payee_get_name_and_report_list();
 	priv->combo_import_asso_payee = gtk_combofix_new_with_properties (tmp_list,
-														   etat.combofix_force_payee,
+														   w_etat->combofix_force_payee,
 														   !w_run->import_asso_case_insensitive,
 														   FALSE,
 														   METATREE_PAYEE);
