@@ -232,7 +232,6 @@ static void widget_transfer_sensitive_direct_debit (WidgetTransfer *dialog,
 	GtkWidget *icon_1;
 	GtkWidget *icon_2;
 	WidgetTransferPrivate *priv;
-devel_debug (NULL);
 
 	priv = widget_transfer_get_instance_private (dialog);
 	icon_1 = g_object_get_data (G_OBJECT (priv->combo_main_payee), "icon");
@@ -445,7 +444,7 @@ static void widget_transfert_select_account_in_treeview (GtkWidget *tree_view,
 
 		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 2, &tmp_number, 3, &type_de_compte, -1);
 
-		if (transfert->type == type_de_compte && tmp_number == transfert->replace_account)
+		if (transfert->type == type_de_compte && tmp_number == transfert->card_account_number)
 		{
 			gtk_tree_selection_select_iter (GTK_TREE_SELECTION (selection), &iter);
 			break;
@@ -868,10 +867,12 @@ static void widget_transfer_setup_card_part (WidgetTransfer *dialog,
 	GtkWidget *combo;
 	GtkWidget *icon;
 	GSList *tmp_list;
+	GrisbiWinEtat *w_etat;
 	WidgetTransferPrivate *priv;
 
 	devel_debug (NULL);
 	priv = widget_transfer_get_instance_private (dialog);
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* set entry_date_bascule */
 	gsb_calendar_entry_new_from_ui (priv->entry_date_bascule, FALSE);
@@ -907,8 +908,8 @@ static void widget_transfer_setup_card_part (WidgetTransfer *dialog,
 
 	tmp_list = gsb_data_payee_get_name_and_report_list ();
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_payee,
-											  etat.combofix_case_sensitive,
+											  w_etat->combofix_force_payee,
+											  w_etat->combofix_case_sensitive,
 											  FALSE,
 											  METATREE_PAYEE);
 	gsb_data_payee_free_name_and_report_list (tmp_list);
@@ -942,9 +943,9 @@ static void widget_transfer_setup_card_part (WidgetTransfer *dialog,
 	/* set categories */
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_category,
-											  etat.combofix_case_sensitive,
-											  etat.combofix_mixed_sort,
+											  w_etat->combofix_force_category,
+											  w_etat->combofix_case_sensitive,
+											  w_etat->combofix_mixed_sort,
 											  METATREE_CATEGORY);
 	gsb_data_categorie_free_name_list (tmp_list);
 
@@ -970,9 +971,9 @@ static void widget_transfer_setup_card_part (WidgetTransfer *dialog,
 	/* set budget */
 	tmp_list = gsb_data_budget_get_name_list (TRUE, TRUE);
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_category,
-											  etat.combofix_case_sensitive,
-											  etat.combofix_mixed_sort,
+											  w_etat->combofix_force_category,
+											  w_etat->combofix_case_sensitive,
+											  w_etat->combofix_mixed_sort,
 											  METATREE_BUDGET);
 	gsb_data_categorie_free_name_list (tmp_list);
 	gtk_grid_attach (GTK_GRID (priv->grid_card_div), combo, 2, 1, 1, 1);
@@ -1011,10 +1012,12 @@ static void widget_transfer_setup_main_part (WidgetTransfer *dialog,
 	GtkWidget *combo;
 	GtkWidget *icon;
 	GSList *tmp_list;
+	GrisbiWinEtat *w_etat;
 	WidgetTransferPrivate *priv;
 
 	devel_debug (NULL);
 	priv = widget_transfer_get_instance_private (dialog);
+	w_etat = grisbi_win_get_w_etat ();
 
 	/* entry_date_debit */
 	gsb_calendar_entry_new_from_ui (priv->entry_date_debit, FALSE);
@@ -1029,8 +1032,8 @@ static void widget_transfer_setup_main_part (WidgetTransfer *dialog,
 
 	tmp_list = gsb_data_payee_get_name_and_report_list ();
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_payee,
-											  etat.combofix_case_sensitive,
+											  w_etat->combofix_force_payee,
+											  w_etat->combofix_case_sensitive,
 											  FALSE,
 											  METATREE_PAYEE);
 	gsb_data_payee_free_name_and_report_list (tmp_list);
@@ -1070,9 +1073,9 @@ static void widget_transfer_setup_main_part (WidgetTransfer *dialog,
 	/* set categories */
 	tmp_list = gsb_data_category_get_name_list (TRUE, TRUE, TRUE, TRUE);
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_category,
-											  etat.combofix_case_sensitive,
-											  etat.combofix_mixed_sort,
+											  w_etat->combofix_force_category,
+											  w_etat->combofix_case_sensitive,
+											  w_etat->combofix_mixed_sort,
 											  METATREE_CATEGORY);
 	gsb_data_categorie_free_name_list (tmp_list);
 
@@ -1098,9 +1101,9 @@ static void widget_transfer_setup_main_part (WidgetTransfer *dialog,
 	/* set budget */
 	tmp_list = gsb_data_budget_get_name_list (TRUE, TRUE);
 	combo = gtk_combofix_new_with_properties (tmp_list,
-											  etat.combofix_force_category,
-											  etat.combofix_case_sensitive,
-											  etat.combofix_mixed_sort,
+											  w_etat->combofix_force_category,
+											  w_etat->combofix_case_sensitive,
+											  w_etat->combofix_mixed_sort,
 											  METATREE_BUDGET);
 	gsb_data_categorie_free_name_list (tmp_list);
 
@@ -1122,8 +1125,11 @@ static void widget_transfer_setup_main_part (WidgetTransfer *dialog,
 					  "focus-out-event",
 					  G_CALLBACK (widget_transfert_div_entry_focus_out),
 					  dialog);
-	/* set checkbuttons */
+
+	/* sensitive main part */
 	widget_transfer_sensitive_direct_debit (dialog, FALSE);
+
+	/* set checkbuttons */
 	if (priv->create_mode)
 	{
 		/* set checkbutton_direct_debit */
@@ -1393,16 +1399,23 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 {
 	GHashTable *transfert_list;
 	gchar *key;
+	gchar *number_str, *account_number_str;
 	TransfertData *transfert;
 	WidgetTransferPrivate *priv;
 
 	devel_debug (NULL);
 	priv = widget_transfer_get_instance_private (WIDGET_TRANSFER (dialog));
 
+	number_str = utils_str_itoa (number);
 	if (account_number == 0)
-		key = g_strconcat ("0:", utils_str_itoa (number), NULL);
+		key = g_strconcat ("0:", number_str, NULL);
 	else
-		key = g_strconcat (utils_str_itoa (account_number), ":", utils_str_itoa (number), NULL);
+	{
+		account_number_str = utils_str_itoa (account_number);
+		key = g_strconcat (account_number_str, ":", number_str, NULL);
+		g_free(account_number_str);
+	}
+	g_free(number_str);
 
 	transfert_list = bet_data_transfert_get_list ();
 
@@ -1470,7 +1483,7 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 	{
 		gsb_payment_method_create_combo_list (priv->combo_card_payment,
 											  GSB_PAYMENT_CREDIT,
-											  transfert->replace_account,
+											  transfert->card_account_number,
 											  0,
 											  FALSE);
 		gtk_widget_set_tooltip_text (GTK_WIDGET (priv->combo_card_payment), _("Choose the method of payment"));
@@ -1488,10 +1501,11 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 	/* set card_category */
 	if (transfert->card_category_number > 0)
 	{
-		gtk_combofix_set_text (GTK_COMBOFIX (priv->combo_card_category),
-							   gsb_data_category_get_name (transfert->card_category_number,
-														   transfert->card_sub_category_number,
-														   NULL));
+		gchar *tmp_str = gsb_data_category_get_name (transfert->card_category_number,
+											  transfert->card_sub_category_number,
+											  NULL);
+		gtk_combofix_set_text (GTK_COMBOFIX (priv->combo_card_category), tmp_str);
+		g_free(tmp_str);
 		gsb_form_widget_set_empty (priv->combo_card_category, FALSE);
 		gtk_editable_set_position (GTK_EDITABLE (gtk_combofix_get_entry
 												 (GTK_COMBOFIX (priv->combo_card_category))), 0);
@@ -1524,6 +1538,10 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 
 	/* main account part */
 
+	/* sensitive main part */
+	if (transfert->direct_debit || transfert->replace_transaction)
+		widget_transfer_sensitive_direct_debit (WIDGET_TRANSFER (dialog), TRUE);
+
 	/* date debit */
 	gsb_calendar_entry_set_date (priv->entry_date_debit, transfert->date_debit);
 	gsb_form_widget_set_empty (priv->entry_date_debit, FALSE);
@@ -1548,11 +1566,13 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 
 		 /* on actualise l'état de l'icone associée */
 		utils_set_image_with_state (priv->combo_main_payee, TRUE);
+		priv->valid_main_payee = TRUE;
    }
 	else
 	{
 		gtk_combofix_set_text (GTK_COMBOFIX (priv->combo_main_payee), _("Payee"));
 		gsb_form_widget_set_empty (priv->combo_main_payee, TRUE);
+		priv->valid_main_payee = FALSE;
 	}
 
 	/* set main_payment_method */
@@ -1566,10 +1586,11 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 	/* set main category */
 	if (transfert->main_category_number > 0)
 	{
-		gtk_combofix_set_text (GTK_COMBOFIX (priv->combo_main_category),
-							   gsb_data_category_get_name (transfert->main_category_number,
-														   transfert->main_sub_category_number,
-														   NULL));
+		gchar *tmp_str = gsb_data_category_get_name (transfert->main_category_number,
+											  transfert->main_sub_category_number,
+											  NULL);
+		gtk_combofix_set_text (GTK_COMBOFIX (priv->combo_main_category), tmp_str);
+		g_free(tmp_str);
 		gsb_form_widget_set_empty (priv->combo_main_category, FALSE);
 		gtk_editable_set_position (GTK_EDITABLE (gtk_combofix_get_entry
 												 (GTK_COMBOFIX (priv->combo_main_category))), 0);
@@ -1599,9 +1620,15 @@ void widget_transfer_fill_data_from_line (GtkWidget *dialog,
 	}
 
 	if (transfert->main_category_number > 0 || transfert->main_budgetary_number > 0)
+	{
 		utils_set_image_with_state (priv->combo_main_budget, TRUE);
+		priv->valid_main_div = TRUE;
+	}
 	else
+	{
 		utils_set_image_with_state (priv->combo_main_budget, FALSE);
+		priv->valid_main_div = FALSE;
+	}
 
 	/* set checkbutton_direct_debit */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->checkbutton_direct_debit), transfert->direct_debit);
@@ -1675,7 +1702,7 @@ TransfertData *widget_transfer_take_data (GtkWidget *dialog,
 		return NULL;
 
 	transfert = struct_initialise_bet_transfert ();
-	transfert->account_number = account_number;
+	transfert->main_account_number = account_number;
 	transfert->number = number;
 
 	gtk_tree_model_get (GTK_TREE_MODEL (model),
@@ -1683,7 +1710,7 @@ TransfertData *widget_transfer_take_data (GtkWidget *dialog,
 						BET_TRANSFER_ACCOUNT, &replace_account,
 						BET_TRANSFERT_PARTIAL, &type,
 						-1);
-	transfert->replace_account = replace_account;
+	transfert->card_account_number = replace_account;
 	transfert->type = type;
 
 	/* Account with deferred debit card */
